from __future__ import annotations

import inspect
import json
import sys
from abc import abstractmethod
from collections.abc import Mapping
from io import BytesIO
from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Literal, Tuple, Union

from typing_extensions import Self, dataclass_transform, get_type_hints

from chalk.utils.pydanticutil.pydantic_compat import is_pydantic_basemodel, is_pydantic_basemodel_instance

BYTEMODEL_MAGIC_STR: str = "CHALK_BYTE_TRANSMISSION"
BYTEMODEL_NUM_LEN_BYTES: int = 8

if TYPE_CHECKING:
    from pydantic import BaseModel


class ByteSerializable:
    @abstractmethod
    def serialize(self) -> bytes:
        ...

    @classmethod
    @abstractmethod
    def deserialize(cls, body_bytes: bytes) -> Self:
        ...


@dataclass_transform()
class ByteBaseModel(ByteSerializable):
    @staticmethod
    def check_len(byte_arr: bytes, start_idx: int, desired_len: int) -> None:
        if start_idx + desired_len > len(byte_arr):
            raise RuntimeError("Tried to consume more bytes than were available!")

    @classmethod
    def produce_len_val(
        cls, start_idx: int, buffer: BytesIO, l: int, endianness: Literal["little", "big"] = "big"
    ) -> Tuple[int, int]:
        len_bytes = l.to_bytes(BYTEMODEL_NUM_LEN_BYTES, endianness)
        buffer.write(len_bytes)
        return start_idx + len(len_bytes), len(len_bytes)

    @classmethod
    def consume_len(
        cls, start_idx: int, bytes_arr: bytes, endianness: Literal["little", "big"] = "big"
    ) -> Tuple[int, int]:
        cls.check_len(bytes_arr, start_idx, BYTEMODEL_NUM_LEN_BYTES)
        return start_idx + BYTEMODEL_NUM_LEN_BYTES, int.from_bytes(
            bytes_arr[start_idx : start_idx + BYTEMODEL_NUM_LEN_BYTES], endianness
        )

    @classmethod
    def consume_magic_str(cls, start_idx: int, candidate_bytes: bytes) -> Tuple[int, None]:
        magic_bytes = BYTEMODEL_MAGIC_STR.encode("utf-8")
        cls.check_len(candidate_bytes, start_idx, len(magic_bytes))
        if magic_bytes != candidate_bytes[start_idx : len(magic_bytes)]:
            raise RuntimeError(f'Failed to find the magic string, "f{BYTEMODEL_MAGIC_STR}".')
        return start_idx + len(magic_bytes), None

    @classmethod
    def produce_magic_str(cls, start_idx: int, buffer: BytesIO) -> Tuple[int, int]:
        magic_str_bytes = BYTEMODEL_MAGIC_STR.encode("utf-8")
        buffer.write(magic_str_bytes)
        return start_idx + len(magic_str_bytes), len(magic_str_bytes)

    @classmethod
    def produce_json_attrs_bytes(cls, start_idx: int, buffer: BytesIO, model: ByteBaseModel) -> Tuple[int, int]:
        attrs_json_bytes = json.dumps(model.get_non_byte_non_pydantic_attr_map()).encode("utf-8")
        cur_idx = start_idx
        cur_idx, _ = cls.produce_len_val(cur_idx, buffer, len(attrs_json_bytes))
        buffer.write(attrs_json_bytes)
        cur_idx += len(attrs_json_bytes)
        return cur_idx, cur_idx - start_idx

    @classmethod
    def consume_json_attrs(cls, start_idx: int, byte_arr: bytes) -> Tuple[int, dict]:
        cur_idx, json_len = cls.consume_len(start_idx, byte_arr)
        cls.check_len(byte_arr, cur_idx, json_len)
        attrs_dict = json.loads(byte_arr[cur_idx : cur_idx + json_len].decode("utf-8"))
        cur_idx += json_len
        return cur_idx, attrs_dict

    @classmethod
    def produce_pydantic_attrs_bytes(cls, start_idx: int, buffer: BytesIO, model: ByteBaseModel) -> Tuple[int, int]:
        pydantic_map: "Dict[str, BaseModel]" = model.get_pydantic_models_map()
        pydantic_as_json_map = {k: v.json() for k, v in pydantic_map.items()}
        pydantic_map_as_bytes = json.dumps(pydantic_as_json_map).encode("utf-8")
        cur_idx = start_idx
        cur_idx, _ = cls.produce_len_val(cur_idx, buffer, len(pydantic_map_as_bytes))
        buffer.write(pydantic_map_as_bytes)
        cur_idx += len(pydantic_map_as_bytes)
        return cur_idx, cur_idx - start_idx

    @classmethod
    def consume_pydantic_attrs(cls, start_idx: int, byte_arr: bytes) -> Tuple[int, dict]:
        cur_idx, json_len = cls.consume_len(start_idx, byte_arr)
        cls.check_len(byte_arr, cur_idx, json_len)
        attrs_dict: Dict = json.loads(byte_arr[cur_idx : cur_idx + json_len].decode("utf-8"))
        cur_idx += json_len
        pydantic_model_classes = [c for c in cls.get_field_annotations().values() if is_pydantic_basemodel(c)]
        pydantic_models_dict = {k: c(**json.loads(v)) for c, (k, v) in zip(pydantic_model_classes, attrs_dict.items())}

        return cur_idx, pydantic_models_dict

    @classmethod
    def create_byte_items_map_bytes(cls, byte_items_map: Dict[str, bytes]) -> bytes:
        return json.dumps({k: len(v) for k, v in byte_items_map.items()}).encode("utf-8")

    @classmethod
    def produce_byte_items_map(
        cls,
        start_idx: int,
        buffer: BytesIO,
        byte_serializable_items_map: Mapping[str, Union[bytes, ByteSerializable]],
    ):
        curr_idx = start_idx
        byte_items_map = {
            k: (v.serialize() if isinstance(v, ByteSerializable) else v) for k, v in byte_serializable_items_map.items()
        }
        data = cls.create_byte_items_map_bytes(byte_items_map)
        curr_idx, _ = cls.produce_len_val(curr_idx, buffer, len(data))
        buffer.write(data)
        curr_idx += len(data)
        return curr_idx, curr_idx - start_idx

    @classmethod
    def produce_byte_items_data(cls, start_idx: int, buffer: BytesIO, bytes_items: Iterable[bytes]) -> Tuple[int, int]:
        curr_idx = start_idx
        for byte_item in bytes_items:
            buffer.write(byte_item)
            curr_idx += len(byte_item)
        return curr_idx, curr_idx - start_idx

    @classmethod
    def consume_byte_items_map(cls, start_idx: int, byte_arr: bytes) -> Tuple[int, Dict[str, int]]:
        cur_idx, json_len = cls.consume_len(start_idx, byte_arr)
        cls.check_len(byte_arr, cur_idx, json_len)
        byte_items_map: Dict[str, int] = json.loads(byte_arr[cur_idx : cur_idx + json_len].decode("utf-8"))
        cur_idx += json_len
        return cur_idx, byte_items_map

    @classmethod
    def consume_byte_items(cls, start_idx: int, byte_arr: bytes) -> Tuple[int, Dict[str, bytes]]:
        cur_idx, byte_items_map = cls.consume_byte_items_map(start_idx, byte_arr)
        attrs_dict: Dict[str, bytes] = {}
        for attr_name, attr_byte_len in byte_items_map.items():
            cls.check_len(byte_arr, start_idx, attr_byte_len)
            attrs_dict[attr_name] = byte_arr[cur_idx : cur_idx + attr_byte_len]
            cur_idx += attr_byte_len
        return cur_idx, attrs_dict

    def get_byte_attr_map(self) -> Dict[str, bytes]:
        return {k: v for k, v in self.dict().items() if isinstance(v, bytes)}

    def get_byte_serializables_map(self):
        return {k: v for k, v in self.dict().items() if isinstance(v, ByteSerializable)}

    def get_pydantic_models_map(self):
        return {k: v for k, v in self.dict().items() if is_pydantic_basemodel_instance(v)}

    def get_non_byte_non_pydantic_attr_map(self) -> Dict[str, Any]:
        return {
            k: v
            for k, v in self.dict().items()
            if not isinstance(v, (bytes, ByteSerializable)) and not is_pydantic_basemodel_instance(v)
        }

    @classmethod
    def get_field_annotations(cls):
        return {k: v for k, v in get_type_hints(cls).items() if not k.startswith("_") and not inspect.ismethod(v)}

    @classmethod
    def get_byte_serializable_classes(cls):
        byte_serializable_classes_in_order: List[type] = []
        for c in cls.get_field_annotations().values():
            if isinstance(c, str):
                if hasattr(sys.modules[__name__], c):
                    c_local = getattr(sys.modules[__name__], c)
                    if inspect.isclass(c_local) and issubclass(c_local, ByteSerializable):
                        byte_serializable_classes_in_order.append(c_local)
            elif inspect.isclass(c) and issubclass(c, ByteSerializable):
                byte_serializable_classes_in_order.append(c)
        return byte_serializable_classes_in_order

    @classmethod
    def deserialize(cls, body_bytes: bytes):
        curr_idx = 0
        curr_idx, _ = cls.consume_magic_str(curr_idx, body_bytes)
        curr_idx, non_byte_attrs = cls.consume_json_attrs(curr_idx, body_bytes)
        curr_idx, pydantic_attrs = cls.consume_pydantic_attrs(curr_idx, body_bytes)
        curr_idx, byte_attrs = cls.consume_byte_items(curr_idx, body_bytes)

        curr_idx, byte_serializables_bytes_items = cls.consume_byte_items(curr_idx, body_bytes)

        final_attrs = {k: v for k, v in non_byte_attrs.items()}
        final_attrs.update(byte_attrs)

        final_attrs.update(pydantic_attrs)

        byte_serializable_attrs = {}

        for (field_name, field_bytes), cls_for_bytes in zip(
            byte_serializables_bytes_items.items(), cls.get_byte_serializable_classes()
        ):
            byte_serializable_attrs[field_name] = cls_for_bytes.deserialize(field_bytes)

        final_attrs.update(byte_serializable_attrs)
        return cls(**final_attrs)

    def dict(self):
        return {k: v for k, v in self.__dict__.items() if k[0] != "_"}

    def __repr__(self):
        return f"{self.__class__.__name__}({str(self.dict())})"

    def serialize(self) -> bytes:
        # Magic str
        # attrs json len
        # attrs json
        # pydantic len
        # pydantic json
        # attr and byte offset json len
        # attr and byte offset json
        # concatenated byte objects
        # attr and byte offset json len
        # attr and byte offsets for serializables
        # concatenated byte objects

        buffer = BytesIO()

        cur_idx = 0

        # regular stuff
        cur_idx, _ = self.produce_magic_str(cur_idx, buffer)
        cur_idx, _ = self.produce_json_attrs_bytes(cur_idx, buffer, self)

        # pydantic objects
        cur_idx, _ = self.produce_pydantic_attrs_bytes(cur_idx, buffer, self)

        # bytes objects
        cur_idx, _ = self.produce_byte_items_map(cur_idx, buffer, self.get_byte_attr_map())
        cur_idx, _ = self.produce_byte_items_data(cur_idx, buffer, self.get_byte_attr_map().values())

        # byte-serializables objects
        byte_serializables_map = self.get_byte_serializables_map()
        cur_idx, _ = self.produce_byte_items_map(cur_idx, buffer, byte_serializables_map)
        cur_idx, _ = self.produce_byte_items_data(
            cur_idx, buffer, [v.serialize() for v in byte_serializables_map.values()]
        )

        buffer.seek(0)

        return buffer.getvalue()

    def __init__(self, **kwargs: Any):
        super().__init__()
        for k, v in kwargs.items():
            self.__setattr__(k, v)

    def __eq__(self, other: object):
        if not isinstance(other, ByteBaseModel):
            return NotImplemented

        if self.get_byte_attr_map() != other.get_byte_attr_map():
            return False

        if self.get_byte_serializables_map() != other.get_byte_serializables_map():
            return False

        if self.get_non_byte_non_pydantic_attr_map() != other.get_non_byte_non_pydantic_attr_map():
            return False

        return True

    def __hash__(self):
        return hash(
            (self.get_byte_attr_map(), self.get_byte_serializables_map(), self.get_non_byte_non_pydantic_attr_map())
        )


class ByteDict(ByteBaseModel):
    def __init__(self, *args: Mapping[str, Any], **kwargs: Any):
        for arg in args:
            if not isinstance(arg, Mapping):  # pyright: ignore[reportUnnecessaryIsInstance]
                raise ValueError(f"Need all args (non-kwargs) in constructor to be dict-like objects. Got: {type(arg)}")
            for k in arg:
                self[k] = arg[k]
        for k, v in kwargs.items():
            self[k] = v

        super().__init__()

    def __setitem__(self, key: str | bytes, value: Union[bytes, ByteSerializable]):
        if not isinstance(key, str):
            raise ValueError(f"Expected key to be a string, got {type(key)}")
        if not isinstance(value, bytes):
            raise ValueError(f"Expected value to be bytes, got {type(value)}")

        self.__dict__[key] = value

    def __getitem__(self, key: str):
        if not isinstance(key, str):  # pyright: ignore[reportUnnecessaryIsInstance]
            raise ValueError(f"Need for keys to be strings, got {type(key)}")
        return self.__dict__[key]

    def __delitem__(self, key: str):
        del self.__dict__[key]

    def __contains__(self, key: str):
        return key in self.dict()

    def __len__(self):
        return len(self.dict())

    def __iter__(self):
        return iter(self.dict())

    def get(self, key: str, default: Any = None) -> Any:
        return self.__dict__.get(key, default)

    def keys(self):
        return self.dict().keys()

    def values(self):
        return self.dict().values()

    def items(self):
        return self.dict().items()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from chalk._gen.chalk.server.v1 import topicpush_pb2 as chalk_dot_server_dot_v1_dot_topicpush__pb2


class TopicPushServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListJobs = channel.unary_unary(
            "/chalk.server.v1.TopicPushService/ListJobs",
            request_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.ListJobsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.ListJobsResponse.FromString,
        )
        self.CreateJob = channel.unary_unary(
            "/chalk.server.v1.TopicPushService/CreateJob",
            request_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.CreateJobRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.CreateJobResponse.FromString,
        )
        self.UpdateJob = channel.unary_unary(
            "/chalk.server.v1.TopicPushService/UpdateJob",
            request_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.UpdateJobRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.UpdateJobResponse.FromString,
        )
        self.DeleteJob = channel.unary_unary(
            "/chalk.server.v1.TopicPushService/DeleteJob",
            request_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.DeleteJobRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.DeleteJobResponse.FromString,
        )
        self.GetJobByName = channel.unary_unary(
            "/chalk.server.v1.TopicPushService/GetJobByName",
            request_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.GetJobByNameRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.GetJobByNameResponse.FromString,
        )


class TopicPushServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetJobByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_TopicPushServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ListJobs": grpc.unary_unary_rpc_method_handler(
            servicer.ListJobs,
            request_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.ListJobsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.ListJobsResponse.SerializeToString,
        ),
        "CreateJob": grpc.unary_unary_rpc_method_handler(
            servicer.CreateJob,
            request_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.CreateJobRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.CreateJobResponse.SerializeToString,
        ),
        "UpdateJob": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateJob,
            request_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.UpdateJobRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.UpdateJobResponse.SerializeToString,
        ),
        "DeleteJob": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteJob,
            request_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.DeleteJobRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.DeleteJobResponse.SerializeToString,
        ),
        "GetJobByName": grpc.unary_unary_rpc_method_handler(
            servicer.GetJobByName,
            request_deserializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.GetJobByNameRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_topicpush__pb2.GetJobByNameResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("chalk.server.v1.TopicPushService", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class TopicPushService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListJobs(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.TopicPushService/ListJobs",
            chalk_dot_server_dot_v1_dot_topicpush__pb2.ListJobsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_topicpush__pb2.ListJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateJob(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.TopicPushService/CreateJob",
            chalk_dot_server_dot_v1_dot_topicpush__pb2.CreateJobRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_topicpush__pb2.CreateJobResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateJob(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.TopicPushService/UpdateJob",
            chalk_dot_server_dot_v1_dot_topicpush__pb2.UpdateJobRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_topicpush__pb2.UpdateJobResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteJob(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.TopicPushService/DeleteJob",
            chalk_dot_server_dot_v1_dot_topicpush__pb2.DeleteJobRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_topicpush__pb2.DeleteJobResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetJobByName(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.TopicPushService/GetJobByName",
            chalk_dot_server_dot_v1_dot_topicpush__pb2.GetJobByNameRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_topicpush__pb2.GetJobByNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from abc import (
    ABCMeta,
    abstractmethod,
)
from chalk._gen.chalk.server.v1.monitoring_pb2 import (
    AddIncidentIoIntegrationRequest,
    AddIncidentIoIntegrationResponse,
    AddPagerDutyIntegrationRequest,
    AddPagerDutyIntegrationResponse,
    DeleteIncidentIoIntegrationRequest,
    DeleteIncidentIoIntegrationResponse,
    DeletePagerDutyIntegrationRequest,
    DeletePagerDutyIntegrationResponse,
    GetAllIncidentIoIntegrationsRequest,
    GetAllIncidentIoIntegrationsResponse,
    GetAllPagerDutyIntegrationsRequest,
    GetAllPagerDutyIntegrationsResponse,
    GetIncidentIoIntegrationRequest,
    GetIncidentIoIntegrationResponse,
    GetPagerDutyIntegrationRequest,
    GetPagerDutyIntegrationResponse,
    SetDefaultPagerDutyIntegrationRequest,
    SetDefaultPagerDutyIntegrationResponse,
    TestIncidentIoIntegrationRequest,
    TestIncidentIoIntegrationResponse,
    TestPagerDutyIntegrationRequest,
    TestPagerDutyIntegrationResponse,
    UpdateIncidentIoIntegrationRequest,
    UpdateIncidentIoIntegrationResponse,
    UpdatePagerDutyIntegrationRequest,
    UpdatePagerDutyIntegrationResponse,
)
from grpc import (
    Channel,
    Server,
    ServicerContext,
    UnaryUnaryMultiCallable,
)

class MonitoringServiceStub:
    def __init__(self, channel: Channel) -> None: ...
    TestPagerDutyIntegration: UnaryUnaryMultiCallable[
        TestPagerDutyIntegrationRequest,
        TestPagerDutyIntegrationResponse,
    ]
    AddPagerDutyIntegration: UnaryUnaryMultiCallable[
        AddPagerDutyIntegrationRequest,
        AddPagerDutyIntegrationResponse,
    ]
    DeletePagerDutyIntegration: UnaryUnaryMultiCallable[
        DeletePagerDutyIntegrationRequest,
        DeletePagerDutyIntegrationResponse,
    ]
    SetDefaultPagerDutyIntegration: UnaryUnaryMultiCallable[
        SetDefaultPagerDutyIntegrationRequest,
        SetDefaultPagerDutyIntegrationResponse,
    ]
    UpdatePagerDutyIntegration: UnaryUnaryMultiCallable[
        UpdatePagerDutyIntegrationRequest,
        UpdatePagerDutyIntegrationResponse,
    ]
    GetAllPagerDutyIntegrations: UnaryUnaryMultiCallable[
        GetAllPagerDutyIntegrationsRequest,
        GetAllPagerDutyIntegrationsResponse,
    ]
    GetPagerDutyIntegration: UnaryUnaryMultiCallable[
        GetPagerDutyIntegrationRequest,
        GetPagerDutyIntegrationResponse,
    ]
    TestIncidentIoIntegration: UnaryUnaryMultiCallable[
        TestIncidentIoIntegrationRequest,
        TestIncidentIoIntegrationResponse,
    ]
    AddIncidentIoIntegration: UnaryUnaryMultiCallable[
        AddIncidentIoIntegrationRequest,
        AddIncidentIoIntegrationResponse,
    ]
    DeleteIncidentIoIntegration: UnaryUnaryMultiCallable[
        DeleteIncidentIoIntegrationRequest,
        DeleteIncidentIoIntegrationResponse,
    ]
    UpdateIncidentIoIntegration: UnaryUnaryMultiCallable[
        UpdateIncidentIoIntegrationRequest,
        UpdateIncidentIoIntegrationResponse,
    ]
    GetAllIncidentIoIntegrations: UnaryUnaryMultiCallable[
        GetAllIncidentIoIntegrationsRequest,
        GetAllIncidentIoIntegrationsResponse,
    ]
    GetIncidentIoIntegration: UnaryUnaryMultiCallable[
        GetIncidentIoIntegrationRequest,
        GetIncidentIoIntegrationResponse,
    ]

class MonitoringServiceServicer(metaclass=ABCMeta):
    @abstractmethod
    def TestPagerDutyIntegration(
        self,
        request: TestPagerDutyIntegrationRequest,
        context: ServicerContext,
    ) -> TestPagerDutyIntegrationResponse: ...
    @abstractmethod
    def AddPagerDutyIntegration(
        self,
        request: AddPagerDutyIntegrationRequest,
        context: ServicerContext,
    ) -> AddPagerDutyIntegrationResponse: ...
    @abstractmethod
    def DeletePagerDutyIntegration(
        self,
        request: DeletePagerDutyIntegrationRequest,
        context: ServicerContext,
    ) -> DeletePagerDutyIntegrationResponse: ...
    @abstractmethod
    def SetDefaultPagerDutyIntegration(
        self,
        request: SetDefaultPagerDutyIntegrationRequest,
        context: ServicerContext,
    ) -> SetDefaultPagerDutyIntegrationResponse: ...
    @abstractmethod
    def UpdatePagerDutyIntegration(
        self,
        request: UpdatePagerDutyIntegrationRequest,
        context: ServicerContext,
    ) -> UpdatePagerDutyIntegrationResponse: ...
    @abstractmethod
    def GetAllPagerDutyIntegrations(
        self,
        request: GetAllPagerDutyIntegrationsRequest,
        context: ServicerContext,
    ) -> GetAllPagerDutyIntegrationsResponse: ...
    @abstractmethod
    def GetPagerDutyIntegration(
        self,
        request: GetPagerDutyIntegrationRequest,
        context: ServicerContext,
    ) -> GetPagerDutyIntegrationResponse: ...
    @abstractmethod
    def TestIncidentIoIntegration(
        self,
        request: TestIncidentIoIntegrationRequest,
        context: ServicerContext,
    ) -> TestIncidentIoIntegrationResponse: ...
    @abstractmethod
    def AddIncidentIoIntegration(
        self,
        request: AddIncidentIoIntegrationRequest,
        context: ServicerContext,
    ) -> AddIncidentIoIntegrationResponse: ...
    @abstractmethod
    def DeleteIncidentIoIntegration(
        self,
        request: DeleteIncidentIoIntegrationRequest,
        context: ServicerContext,
    ) -> DeleteIncidentIoIntegrationResponse: ...
    @abstractmethod
    def UpdateIncidentIoIntegration(
        self,
        request: UpdateIncidentIoIntegrationRequest,
        context: ServicerContext,
    ) -> UpdateIncidentIoIntegrationResponse: ...
    @abstractmethod
    def GetAllIncidentIoIntegrations(
        self,
        request: GetAllIncidentIoIntegrationsRequest,
        context: ServicerContext,
    ) -> GetAllIncidentIoIntegrationsResponse: ...
    @abstractmethod
    def GetIncidentIoIntegration(
        self,
        request: GetIncidentIoIntegrationRequest,
        context: ServicerContext,
    ) -> GetIncidentIoIntegrationResponse: ...

def add_MonitoringServiceServicer_to_server(servicer: MonitoringServiceServicer, server: Server) -> None: ...



import enum
import functools
import inspect
import sys
from contextvars import ContextVar
from typing import TYPE_CHECKING, Any, Optional

from chalk.utils.environment_parsing import env_var_bool

if TYPE_CHECKING:
    from chalk.sql._internal.sql_file_resolver import SQLStringResult


def print_user_error(message: str, exception: Optional[Exception] = None, suggested_action: Optional[str] = None):
    print(f"\033[91mERROR: {message}\033[0m", file=sys.stderr)

    if exception is not None:
        print(f"\033[93mDetails: {str(exception)}\033[0m", file=sys.stderr)

    if suggested_action is not None:
        print(f"\033[94mSuggested action: {suggested_action}.\033[0m", file=sys.stderr)


class IPythonEvents(enum.Enum):
    SHELL_INITIALIZED = "shell_initialized"
    PRE_EXECUTE = "pre_execute"
    PRE_RUN_CELL = "pre_run_cell"
    POST_EXECUTE = "post_execute"
    POST_RUN_CELL = "post_run_cell"


def get_ipython_or_none() -> Optional[object]:
    """
    Returns the global IPython shell object, if this code is running in an ipython environment.
    :return: An `IPython.core.interactiveshell.InteractiveShell`, or None if we're not running in a notebook/ipython repl
    """
    try:
        # This method only exists if we're running inside an ipython env
        return get_ipython()  # type: ignore
    except NameError:
        return None  # Probably standard Python interpreter


_is_notebook_override: bool = env_var_bool("CHALK_IS_NOTEBOOK_OVERRIDE")

"""
For testing, this variable can be set to simulate running inside a notebook. If None, ignored. If true/false, that value is returned by is_notebook().
Note that `is_notebook()` caches its results to must be called _after_ setting this value.
"""


@functools.lru_cache(maxsize=None)
def _is_notebook() -> bool:
    """:return: true if run inside a Jupyter notebook"""
    if _is_notebook_override:
        return True
    shell = get_ipython_or_none()
    if shell is None:
        return False
    # Check MRO since some envs (e.g. DataBricks) subclass the kernel
    for c in shell.__class__.__mro__:
        cname: str = c.__name__
        if cname == "ZMQInteractiveShell":
            return True
        if cname == "TerminalInteractiveShell":
            return False  # ipython running in terminal
    return False


def is_notebook() -> bool:
    # Delegate so it's easier to monkeypatch
    return _is_notebook()


notebook_features_loaded: ContextVar[bool] = ContextVar("notebook_features_loaded", default=False)


def check_in_notebook(msg: Optional[str] = None):
    if not is_notebook():
        if msg is None:
            msg = "Not running inside a Jupyter kernel."
        raise RuntimeError(msg)


def is_defined_in_module(obj: Any) -> bool:
    """
    Whether the given object was defined in a module that was imported, or if it's defined at the top level of a shell/script.
    :return: True if object was defined inside a module.
    """
    m = inspect.getmodule(obj)
    if m is None:
        return False
    return m.__name__ != "__main__"


def is_defined_in_cell_magic(obj: Any) -> bool:
    from chalk.features import Resolver

    if isinstance(obj, Resolver):
        return obj.is_cell_magic
    return False


def register_resolver_from_cell_magic(sql_string_result: "SQLStringResult"):
    """Registers a resolver from the %%sql_resolver cell magic.
    Parameters
    ----------
    sql_string_result
    """
    from chalk.sql._internal.sql_file_resolver import NOTEBOOK_DEFINED_SQL_RESOLVERS, get_sql_file_resolver
    from chalk.sql._internal.sql_source import BaseSQLSource

    if sql_string_result.path == "":
        print_user_error(
            "Resolver name is required, but none found. Please add a name to the first line of the cell, like %%resolver my_resolver.",
        )
        return

    resolver_result = get_sql_file_resolver(
        sources=BaseSQLSource.registry, sql_string_result=sql_string_result, has_import_errors=False
    )
    if resolver_result.errors:
        errs = [e.display for e in resolver_result.errors]
        err_message = "\n".join(errs)

        print_user_error(
            f"Failed to parse notebook-defined SQL resolver '{sql_string_result.path}'. Found the following errors:\n{err_message}",
        )
        return

    NOTEBOOK_DEFINED_SQL_RESOLVERS[sql_string_result.path] = resolver_result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/expression/v1/expression.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chalk._gen.chalk.arrow.v1 import arrow_pb2 as chalk_dot_arrow_dot_v1_dot_arrow__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n$chalk/expression/v1/expression.proto\x12\x13\x63halk.expression.v1\x1a\x1a\x63halk/arrow/v1/arrow.proto" \n\nIdentifier\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name"\x8f\x01\n\x10\x45xprGetAttribute\x12<\n\x06parent\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x06parent\x12=\n\tattribute\x18\x02 \x01(\x0b\x32\x1f.chalk.expression.v1.IdentifierR\tattribute"\x94\x01\n\x10\x45xprGetSubscript\x12<\n\x06parent\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x06parent\x12\x42\n\tsubscript\x18\x02 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\tsubscript"\xa2\x02\n\x08\x45xprCall\x12\x38\n\x04\x66unc\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x66unc\x12\x38\n\x04\x61rgs\x18\x02 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x61rgs\x12\x41\n\x06kwargs\x18\x03 \x03(\x0b\x32).chalk.expression.v1.ExprCall.KwargsEntryR\x06kwargs\x1a_\n\x0bKwargsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12:\n\x05value\x18\x02 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x05value:\x02\x38\x01"u\n\x0b\x45xprLiteral\x12\x31\n\x05value\x18\x01 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueR\x05value\x12\x33\n\x16is_arrow_scalar_object\x18\x02 \x01(\x08R\x13isArrowScalarObject"\xe1\x15\n\x0fLogicalExprNode\x12\x41\n\nidentifier\x18# \x01(\x0b\x32\x1f.chalk.expression.v1.IdentifierH\x00R\nidentifier\x12L\n\rget_attribute\x18$ \x01(\x0b\x32%.chalk.expression.v1.ExprGetAttributeH\x00R\x0cgetAttribute\x12L\n\rget_subscript\x18% \x01(\x0b\x32%.chalk.expression.v1.ExprGetSubscriptH\x00R\x0cgetSubscript\x12\x33\n\x04\x63\x61ll\x18& \x01(\x0b\x32\x1d.chalk.expression.v1.ExprCallH\x00R\x04\x63\x61ll\x12G\n\rliteral_value\x18\' \x01(\x0b\x32 .chalk.expression.v1.ExprLiteralH\x00R\x0cliteralValue\x12\x17\n\x07\x65xpr_id\x18( \x01(\tR\x06\x65xprId\x12\x39\n\x06\x63olumn\x18\x01 \x01(\x0b\x32\x1b.chalk.expression.v1.ColumnB\x02\x18\x01H\x01R\x06\x63olumn\x12:\n\x05\x61lias\x18\x02 \x01(\x0b\x32\x1e.chalk.expression.v1.AliasNodeB\x02\x18\x01H\x01R\x05\x61lias\x12;\n\x07literal\x18\x03 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueB\x02\x18\x01H\x01R\x07literal\x12J\n\x0b\x62inary_expr\x18\x04 \x01(\x0b\x32#.chalk.expression.v1.BinaryExprNodeB\x02\x18\x01H\x01R\nbinaryExpr\x12S\n\x0e\x61ggregate_expr\x18\x05 \x01(\x0b\x32&.chalk.expression.v1.AggregateExprNodeB\x02\x18\x01H\x01R\raggregateExpr\x12\x43\n\x0cis_null_expr\x18\x06 \x01(\x0b\x32\x1b.chalk.expression.v1.IsNullB\x02\x18\x01H\x01R\nisNullExpr\x12M\n\x10is_not_null_expr\x18\x07 \x01(\x0b\x32\x1e.chalk.expression.v1.IsNotNullB\x02\x18\x01H\x01R\risNotNullExpr\x12\x39\n\x08not_expr\x18\x08 \x01(\x0b\x32\x18.chalk.expression.v1.NotB\x02\x18\x01H\x01R\x07notExpr\x12@\n\x07\x62\x65tween\x18\t \x01(\x0b\x32 .chalk.expression.v1.BetweenNodeB\x02\x18\x01H\x01R\x07\x62\x65tween\x12\x37\n\x04\x63\x61se\x18\n \x01(\x0b\x32\x1d.chalk.expression.v1.CaseNodeB\x02\x18\x01H\x01R\x04\x63\x61se\x12\x37\n\x04\x63\x61st\x18\x0b \x01(\x0b\x32\x1d.chalk.expression.v1.CastNodeB\x02\x18\x01H\x01R\x04\x63\x61st\x12;\n\x04sort\x18\x0c \x01(\x0b\x32!.chalk.expression.v1.SortExprNodeB\x02\x18\x01H\x01R\x04sort\x12\x43\n\x08negative\x18\r \x01(\x0b\x32!.chalk.expression.v1.NegativeNodeB\x02\x18\x01H\x01R\x08negative\x12>\n\x07in_list\x18\x0e \x01(\x0b\x32\x1f.chalk.expression.v1.InListNodeB\x02\x18\x01H\x01R\x06inList\x12?\n\x08wildcard\x18\x0f \x01(\x0b\x32\x1d.chalk.expression.v1.WildcardB\x02\x18\x01H\x01R\x08wildcard\x12V\n\x0fscalar_function\x18\x10 \x01(\x0b\x32\'.chalk.expression.v1.ScalarFunctionNodeB\x02\x18\x01H\x01R\x0escalarFunction\x12\x41\n\x08try_cast\x18\x11 \x01(\x0b\x32 .chalk.expression.v1.TryCastNodeB\x02\x18\x01H\x01R\x07tryCast\x12J\n\x0bwindow_expr\x18\x12 \x01(\x0b\x32#.chalk.expression.v1.WindowExprNodeB\x02\x18\x01H\x01R\nwindowExpr\x12]\n\x12\x61ggregate_udf_expr\x18\x13 \x01(\x0b\x32).chalk.expression.v1.AggregateUDFExprNodeB\x02\x18\x01H\x01R\x10\x61ggregateUdfExpr\x12T\n\x0fscalar_udf_expr\x18\x14 \x01(\x0b\x32&.chalk.expression.v1.ScalarUDFExprNodeB\x02\x18\x01H\x01R\rscalarUdfExpr\x12V\n\x11get_indexed_field\x18\x15 \x01(\x0b\x32$.chalk.expression.v1.GetIndexedFieldB\x02\x18\x01H\x01R\x0fgetIndexedField\x12M\n\x0cgrouping_set\x18\x16 \x01(\x0b\x32$.chalk.expression.v1.GroupingSetNodeB\x02\x18\x01H\x01R\x0bgroupingSet\x12\x37\n\x04\x63ube\x18\x17 \x01(\x0b\x32\x1d.chalk.expression.v1.CubeNodeB\x02\x18\x01H\x01R\x04\x63ube\x12=\n\x06rollup\x18\x18 \x01(\x0b\x32\x1f.chalk.expression.v1.RollupNodeB\x02\x18\x01H\x01R\x06rollup\x12:\n\x07is_true\x18\x19 \x01(\x0b\x32\x1b.chalk.expression.v1.IsTrueB\x02\x18\x01H\x01R\x06isTrue\x12=\n\x08is_false\x18\x1a \x01(\x0b\x32\x1c.chalk.expression.v1.IsFalseB\x02\x18\x01H\x01R\x07isFalse\x12\x43\n\nis_unknown\x18\x1b \x01(\x0b\x32\x1e.chalk.expression.v1.IsUnknownB\x02\x18\x01H\x01R\tisUnknown\x12\x44\n\x0bis_not_true\x18\x1c \x01(\x0b\x32\x1e.chalk.expression.v1.IsNotTrueB\x02\x18\x01H\x01R\tisNotTrue\x12G\n\x0cis_not_false\x18\x1d \x01(\x0b\x32\x1f.chalk.expression.v1.IsNotFalseB\x02\x18\x01H\x01R\nisNotFalse\x12M\n\x0eis_not_unknown\x18\x1e \x01(\x0b\x32!.chalk.expression.v1.IsNotUnknownB\x02\x18\x01H\x01R\x0cisNotUnknown\x12\x37\n\x04like\x18\x1f \x01(\x0b\x32\x1d.chalk.expression.v1.LikeNodeB\x02\x18\x01H\x01R\x04like\x12:\n\x05ilike\x18  \x01(\x0b\x32\x1e.chalk.expression.v1.ILikeNodeB\x02\x18\x01H\x01R\x05ilike\x12G\n\nsimilar_to\x18! \x01(\x0b\x32".chalk.expression.v1.SimilarToNodeB\x02\x18\x01H\x01R\tsimilarTo\x12L\n\x0bplaceholder\x18" \x01(\x0b\x32$.chalk.expression.v1.PlaceholderNodeB\x02\x18\x01H\x01R\x0bplaceholderB\x0b\n\texpr_formB\x0b\n\texpr_type",\n\x0e\x43olumnRelation\x12\x1a\n\x08relation\x18\x01 \x01(\tR\x08relation"]\n\x06\x43olumn\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x08relation\x18\x02 \x01(\x0b\x32#.chalk.expression.v1.ColumnRelationR\x08relation";\n\x08Wildcard\x12!\n\tqualifier\x18\x01 \x01(\tH\x00R\tqualifier\x88\x01\x01\x42\x0c\n\n_qualifier"Y\n\x0fPlaceholderNode\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x36\n\tdata_type\x18\x02 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\x08\x64\x61taType"K\n\x0fLogicalExprList\x12\x38\n\x04\x65xpr\x18\x01 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"K\n\x0fGroupingSetNode\x12\x38\n\x04\x65xpr\x18\x01 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprListR\x04\x65xpr"D\n\x08\x43ubeNode\x12\x38\n\x04\x65xpr\x18\x01 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"F\n\nRollupNode\x12\x38\n\x04\x65xpr\x18\x01 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"C\n\x10NamedStructField\x12/\n\x04name\x18\x01 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueR\x04name"C\n\tListIndex\x12\x36\n\x03key\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x03key"\x81\x01\n\tListRange\x12:\n\x05start\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x05start\x12\x38\n\x04stop\x18\x02 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04stop"\xad\x02\n\x0fGetIndexedField\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12U\n\x12named_struct_field\x18\x02 \x01(\x0b\x32%.chalk.expression.v1.NamedStructFieldH\x00R\x10namedStructField\x12?\n\nlist_index\x18\x03 \x01(\x0b\x32\x1e.chalk.expression.v1.ListIndexH\x00R\tlistIndex\x12?\n\nlist_range\x18\x04 \x01(\x0b\x32\x1e.chalk.expression.v1.ListRangeH\x00R\tlistRangeB\x07\n\x05\x66ield"B\n\x06IsNull\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"E\n\tIsNotNull\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"B\n\x06IsTrue\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"C\n\x07IsFalse\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"E\n\tIsUnknown\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"E\n\tIsNotTrue\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"F\n\nIsNotFalse\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"H\n\x0cIsNotUnknown\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"?\n\x03Not\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"\xa1\x01\n\tAliasNode\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12\x14\n\x05\x61lias\x18\x02 \x01(\tR\x05\x61lias\x12\x44\n\x08relation\x18\x03 \x03(\x0b\x32(.chalk.expression.v1.OwnedTableReferenceR\x08relation"*\n\x12\x42\x61reTableReference\x12\x14\n\x05table\x18\x01 \x01(\tR\x05table"E\n\x15PartialTableReference\x12\x16\n\x06schema\x18\x01 \x01(\tR\x06schema\x12\x14\n\x05table\x18\x02 \x01(\tR\x05table"\\\n\x12\x46ullTableReference\x12\x18\n\x07\x63\x61talog\x18\x01 \x01(\tR\x07\x63\x61talog\x12\x16\n\x06schema\x18\x02 \x01(\tR\x06schema\x12\x14\n\x05table\x18\x03 \x01(\tR\x05table"\xf3\x01\n\x13OwnedTableReference\x12=\n\x04\x62\x61re\x18\x01 \x01(\x0b\x32\'.chalk.expression.v1.BareTableReferenceH\x00R\x04\x62\x61re\x12\x46\n\x07partial\x18\x02 \x01(\x0b\x32*.chalk.expression.v1.PartialTableReferenceH\x00R\x07partial\x12=\n\x04\x66ull\x18\x03 \x01(\x0b\x32\'.chalk.expression.v1.FullTableReferenceH\x00R\x04\x66ullB\x16\n\x14table_reference_enum"b\n\x0e\x42inaryExprNode\x12@\n\x08operands\x18\x01 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x08operands\x12\x0e\n\x02op\x18\x03 \x01(\tR\x02op"H\n\x0cNegativeNode\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr"\x9a\x01\n\nInListNode\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12\x38\n\x04list\x18\x02 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04list\x12\x18\n\x07negated\x18\x03 \x01(\x08R\x07negated"\x85\x01\n\x12ScalarFunctionNode\x12\x35\n\x03\x66un\x18\x01 \x01(\x0e\x32#.chalk.expression.v1.ScalarFunctionR\x03\x66un\x12\x38\n\x04\x61rgs\x18\x02 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x61rgs"\xb5\x02\n\x11\x41ggregateExprNode\x12K\n\raggr_function\x18\x01 \x01(\x0e\x32&.chalk.expression.v1.AggregateFunctionR\x0c\x61ggrFunction\x12\x38\n\x04\x65xpr\x18\x02 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12\x1a\n\x08\x64istinct\x18\x03 \x01(\x08R\x08\x64istinct\x12<\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x06\x66ilter\x12?\n\x08order_by\x18\x05 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x07orderBy"\x9a\x03\n\x14\x41ggregateUDFExprNode\x12\x19\n\x08\x66un_name\x18\x01 \x01(\tR\x07\x66unName\x12\x38\n\x04\x61rgs\x18\x02 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x61rgs\x12<\n\x06\x66ilter\x18\x03 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x06\x66ilter\x12?\n\x08order_by\x18\x04 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x07orderBy\x12M\n\x06kwargs\x18\x05 \x03(\x0b\x32\x35.chalk.expression.v1.AggregateUDFExprNode.KwargsEntryR\x06kwargs\x1a_\n\x0bKwargsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12:\n\x05value\x18\x02 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x05value:\x02\x38\x01"h\n\x11ScalarUDFExprNode\x12\x19\n\x08\x66un_name\x18\x01 \x01(\tR\x07\x66unName\x12\x38\n\x04\x61rgs\x18\x02 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x61rgs"\x81\x04\n\x0eWindowExprNode\x12M\n\raggr_function\x18\x01 \x01(\x0e\x32&.chalk.expression.v1.AggregateFunctionH\x00R\x0c\x61ggrFunction\x12X\n\x11\x62uilt_in_function\x18\x02 \x01(\x0e\x32*.chalk.expression.v1.BuiltInWindowFunctionH\x00R\x0f\x62uiltInFunction\x12\x14\n\x04udaf\x18\x03 \x01(\tH\x00R\x04udaf\x12\x14\n\x04udwf\x18\t \x01(\tH\x00R\x04udwf\x12\x38\n\x04\x65xpr\x18\x04 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12G\n\x0cpartition_by\x18\x05 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x0bpartitionBy\x12?\n\x08order_by\x18\x06 \x03(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x07orderBy\x12\x43\n\x0cwindow_frame\x18\x08 \x01(\x0b\x32 .chalk.expression.v1.WindowFrameR\x0bwindowFrameB\x11\n\x0fwindow_function"\xd3\x01\n\x0b\x42\x65tweenNode\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12\x18\n\x07negated\x18\x02 \x01(\x08R\x07negated\x12\x36\n\x03low\x18\x03 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x03low\x12\x38\n\x04high\x18\x04 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04high"\xbf\x01\n\x08LikeNode\x12\x18\n\x07negated\x18\x01 \x01(\x08R\x07negated\x12\x38\n\x04\x65xpr\x18\x02 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12>\n\x07pattern\x18\x03 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x07pattern\x12\x1f\n\x0b\x65scape_char\x18\x04 \x01(\tR\nescapeChar"\xc0\x01\n\tILikeNode\x12\x18\n\x07negated\x18\x01 \x01(\x08R\x07negated\x12\x38\n\x04\x65xpr\x18\x02 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12>\n\x07pattern\x18\x03 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x07pattern\x12\x1f\n\x0b\x65scape_char\x18\x04 \x01(\tR\nescapeChar"\xc4\x01\n\rSimilarToNode\x12\x18\n\x07negated\x18\x01 \x01(\x08R\x07negated\x12\x38\n\x04\x65xpr\x18\x02 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12>\n\x07pattern\x18\x03 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x07pattern\x12\x1f\n\x0b\x65scape_char\x18\x04 \x01(\tR\nescapeChar"\xcc\x01\n\x08\x43\x61seNode\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12\x43\n\x0ewhen_then_expr\x18\x02 \x03(\x0b\x32\x1d.chalk.expression.v1.WhenThenR\x0cwhenThenExpr\x12\x41\n\telse_expr\x18\x03 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x08\x65lseExpr"\x90\x01\n\x08WhenThen\x12\x41\n\twhen_expr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x08whenExpr\x12\x41\n\tthen_expr\x18\x02 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x08thenExpr"~\n\x08\x43\x61stNode\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12\x38\n\narrow_type\x18\x02 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\tarrowType"\x81\x01\n\x0bTryCastNode\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12\x38\n\narrow_type\x18\x02 \x01(\x0b\x32\x19.chalk.arrow.v1.ArrowTypeR\tarrowType"{\n\x0cSortExprNode\x12\x38\n\x04\x65xpr\x18\x01 \x01(\x0b\x32$.chalk.expression.v1.LogicalExprNodeR\x04\x65xpr\x12\x10\n\x03\x61sc\x18\x02 \x01(\x08R\x03\x61sc\x12\x1f\n\x0bnulls_first\x18\x03 \x01(\x08R\nnullsFirst"\xf6\x01\n\x0bWindowFrame\x12S\n\x12window_frame_units\x18\x01 \x01(\x0e\x32%.chalk.expression.v1.WindowFrameUnitsR\x10windowFrameUnits\x12\x46\n\x0bstart_bound\x18\x02 \x01(\x0b\x32%.chalk.expression.v1.WindowFrameBoundR\nstartBound\x12@\n\x05\x62ound\x18\x03 \x01(\x0b\x32%.chalk.expression.v1.WindowFrameBoundH\x00R\x05\x62ound\x88\x01\x01\x42\x08\n\x06_bound"\xb2\x01\n\x10WindowFrameBound\x12`\n\x17window_frame_bound_type\x18\x01 \x01(\x0e\x32).chalk.expression.v1.WindowFrameBoundTypeR\x14windowFrameBoundType\x12<\n\x0b\x62ound_value\x18\x02 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueR\nboundValue*\xa0\x1f\n\x0eScalarFunction\x12\x1f\n\x1bSCALAR_FUNCTION_UNSPECIFIED\x10\x00\x12\x17\n\x13SCALAR_FUNCTION_ABS\x10\x01\x12\x18\n\x14SCALAR_FUNCTION_ACOS\x10\x02\x12\x18\n\x14SCALAR_FUNCTION_ASIN\x10\x03\x12\x18\n\x14SCALAR_FUNCTION_ATAN\x10\x04\x12\x19\n\x15SCALAR_FUNCTION_ASCII\x10\x05\x12\x18\n\x14SCALAR_FUNCTION_CEIL\x10\x06\x12\x17\n\x13SCALAR_FUNCTION_COS\x10\x07\x12\x1a\n\x16SCALAR_FUNCTION_DIGEST\x10\x08\x12\x17\n\x13SCALAR_FUNCTION_EXP\x10\t\x12\x19\n\x15SCALAR_FUNCTION_FLOOR\x10\n\x12\x16\n\x12SCALAR_FUNCTION_LN\x10\x0b\x12\x17\n\x13SCALAR_FUNCTION_LOG\x10\x0c\x12\x19\n\x15SCALAR_FUNCTION_LOG10\x10\r\x12\x18\n\x14SCALAR_FUNCTION_LOG2\x10\x0e\x12\x19\n\x15SCALAR_FUNCTION_ROUND\x10\x0f\x12\x1a\n\x16SCALAR_FUNCTION_SIGNUM\x10\x10\x12\x17\n\x13SCALAR_FUNCTION_SIN\x10\x11\x12\x18\n\x14SCALAR_FUNCTION_SQRT\x10\x12\x12\x17\n\x13SCALAR_FUNCTION_TAN\x10\x13\x12\x19\n\x15SCALAR_FUNCTION_TRUNC\x10\x14\x12\x19\n\x15SCALAR_FUNCTION_ARRAY\x10\x15\x12 \n\x1cSCALAR_FUNCTION_REGEXP_MATCH\x10\x16\x12\x1e\n\x1aSCALAR_FUNCTION_BIT_LENGTH\x10\x17\x12\x19\n\x15SCALAR_FUNCTION_BTRIM\x10\x18\x12$\n SCALAR_FUNCTION_CHARACTER_LENGTH\x10\x19\x12\x17\n\x13SCALAR_FUNCTION_CHR\x10\x1a\x12\x1a\n\x16SCALAR_FUNCTION_CONCAT\x10\x1b\x12)\n%SCALAR_FUNCTION_CONCAT_WITH_SEPARATOR\x10\x1c\x12\x1d\n\x19SCALAR_FUNCTION_DATE_PART\x10\x1d\x12\x1e\n\x1aSCALAR_FUNCTION_DATE_TRUNC\x10\x1e\x12\x1c\n\x18SCALAR_FUNCTION_INIT_CAP\x10\x1f\x12\x18\n\x14SCALAR_FUNCTION_LEFT\x10 \x12\x18\n\x14SCALAR_FUNCTION_LPAD\x10!\x12\x19\n\x15SCALAR_FUNCTION_LOWER\x10"\x12\x19\n\x15SCALAR_FUNCTION_LTRIM\x10#\x12\x17\n\x13SCALAR_FUNCTION_MD5\x10$\x12\x1b\n\x17SCALAR_FUNCTION_NULL_IF\x10%\x12 \n\x1cSCALAR_FUNCTION_OCTET_LENGTH\x10&\x12\x1a\n\x16SCALAR_FUNCTION_RANDOM\x10\'\x12"\n\x1eSCALAR_FUNCTION_REGEXP_REPLACE\x10(\x12\x1a\n\x16SCALAR_FUNCTION_REPEAT\x10)\x12\x1b\n\x17SCALAR_FUNCTION_REPLACE\x10*\x12\x1b\n\x17SCALAR_FUNCTION_REVERSE\x10+\x12\x19\n\x15SCALAR_FUNCTION_RIGHT\x10,\x12\x18\n\x14SCALAR_FUNCTION_RPAD\x10-\x12\x19\n\x15SCALAR_FUNCTION_RTRIM\x10.\x12\x1a\n\x16SCALAR_FUNCTION_SHA224\x10/\x12\x1a\n\x16SCALAR_FUNCTION_SHA256\x10\x30\x12\x1a\n\x16SCALAR_FUNCTION_SHA384\x10\x31\x12\x1a\n\x16SCALAR_FUNCTION_SHA512\x10\x32\x12\x1e\n\x1aSCALAR_FUNCTION_SPLIT_PART\x10\x33\x12\x1f\n\x1bSCALAR_FUNCTION_STARTS_WITH\x10\x34\x12\x1a\n\x16SCALAR_FUNCTION_STRPOS\x10\x35\x12\x1a\n\x16SCALAR_FUNCTION_SUBSTR\x10\x36\x12\x1a\n\x16SCALAR_FUNCTION_TO_HEX\x10\x37\x12 \n\x1cSCALAR_FUNCTION_TO_TIMESTAMP\x10\x38\x12\'\n#SCALAR_FUNCTION_TO_TIMESTAMP_MILLIS\x10\x39\x12\'\n#SCALAR_FUNCTION_TO_TIMESTAMP_MICROS\x10:\x12(\n$SCALAR_FUNCTION_TO_TIMESTAMP_SECONDS\x10;\x12\x17\n\x13SCALAR_FUNCTION_NOW\x10<\x12\x1d\n\x19SCALAR_FUNCTION_TRANSLATE\x10=\x12\x18\n\x14SCALAR_FUNCTION_TRIM\x10>\x12\x19\n\x15SCALAR_FUNCTION_UPPER\x10?\x12\x1c\n\x18SCALAR_FUNCTION_COALESCE\x10@\x12\x19\n\x15SCALAR_FUNCTION_POWER\x10\x41\x12\x1e\n\x1aSCALAR_FUNCTION_STRUCT_FUN\x10\x42\x12!\n\x1dSCALAR_FUNCTION_FROM_UNIXTIME\x10\x43\x12\x19\n\x15SCALAR_FUNCTION_ATAN2\x10\x44\x12\x1c\n\x18SCALAR_FUNCTION_DATE_BIN\x10\x45\x12 \n\x1cSCALAR_FUNCTION_ARROW_TYPEOF\x10\x46\x12 \n\x1cSCALAR_FUNCTION_CURRENT_DATE\x10G\x12 \n\x1cSCALAR_FUNCTION_CURRENT_TIME\x10H\x12\x18\n\x14SCALAR_FUNCTION_UUID\x10I\x12\x18\n\x14SCALAR_FUNCTION_CBRT\x10J\x12\x19\n\x15SCALAR_FUNCTION_ACOSH\x10K\x12\x19\n\x15SCALAR_FUNCTION_ASINH\x10L\x12\x19\n\x15SCALAR_FUNCTION_ATANH\x10M\x12\x18\n\x14SCALAR_FUNCTION_SINH\x10N\x12\x18\n\x14SCALAR_FUNCTION_COSH\x10O\x12\x18\n\x14SCALAR_FUNCTION_TANH\x10P\x12\x16\n\x12SCALAR_FUNCTION_PI\x10Q\x12\x1b\n\x17SCALAR_FUNCTION_DEGREES\x10R\x12\x1b\n\x17SCALAR_FUNCTION_RADIANS\x10S\x12\x1d\n\x19SCALAR_FUNCTION_FACTORIAL\x10T\x12\x17\n\x13SCALAR_FUNCTION_LCM\x10U\x12\x17\n\x13SCALAR_FUNCTION_GCD\x10V\x12 \n\x1cSCALAR_FUNCTION_ARRAY_APPEND\x10W\x12 \n\x1cSCALAR_FUNCTION_ARRAY_CONCAT\x10X\x12\x1e\n\x1aSCALAR_FUNCTION_ARRAY_DIMS\x10Y\x12 \n\x1cSCALAR_FUNCTION_ARRAY_REPEAT\x10Z\x12 \n\x1cSCALAR_FUNCTION_ARRAY_LENGTH\x10[\x12\x1f\n\x1bSCALAR_FUNCTION_ARRAY_NDIMS\x10\\\x12"\n\x1eSCALAR_FUNCTION_ARRAY_POSITION\x10]\x12#\n\x1fSCALAR_FUNCTION_ARRAY_POSITIONS\x10^\x12!\n\x1dSCALAR_FUNCTION_ARRAY_PREPEND\x10_\x12 \n\x1cSCALAR_FUNCTION_ARRAY_REMOVE\x10`\x12!\n\x1dSCALAR_FUNCTION_ARRAY_REPLACE\x10\x61\x12#\n\x1fSCALAR_FUNCTION_ARRAY_TO_STRING\x10\x62\x12\x1f\n\x1bSCALAR_FUNCTION_CARDINALITY\x10\x63\x12!\n\x1dSCALAR_FUNCTION_ARRAY_ELEMENT\x10\x64\x12\x1f\n\x1bSCALAR_FUNCTION_ARRAY_SLICE\x10\x65\x12\x1a\n\x16SCALAR_FUNCTION_ENCODE\x10\x66\x12\x1a\n\x16SCALAR_FUNCTION_DECODE\x10g\x12\x17\n\x13SCALAR_FUNCTION_COT\x10h\x12\x1d\n\x19SCALAR_FUNCTION_ARRAY_HAS\x10i\x12!\n\x1dSCALAR_FUNCTION_ARRAY_HAS_ANY\x10j\x12!\n\x1dSCALAR_FUNCTION_ARRAY_HAS_ALL\x10k\x12"\n\x1eSCALAR_FUNCTION_ARRAY_REMOVE_N\x10l\x12#\n\x1fSCALAR_FUNCTION_ARRAY_REPLACE_N\x10m\x12$\n SCALAR_FUNCTION_ARRAY_REMOVE_ALL\x10n\x12%\n!SCALAR_FUNCTION_ARRAY_REPLACE_ALL\x10o\x12\x19\n\x15SCALAR_FUNCTION_NANVL\x10p\x12\x1b\n\x17SCALAR_FUNCTION_FLATTEN\x10q\x12\x19\n\x15SCALAR_FUNCTION_ISNAN\x10r\x12\x1a\n\x16SCALAR_FUNCTION_ISZERO\x10s\x12\x1f\n\x1bSCALAR_FUNCTION_ARRAY_EMPTY\x10t\x12"\n\x1eSCALAR_FUNCTION_ARRAY_POP_BACK\x10u\x12#\n\x1fSCALAR_FUNCTION_STRING_TO_ARRAY\x10v\x12&\n"SCALAR_FUNCTION_TO_TIMESTAMP_NANOS\x10w\x12#\n\x1fSCALAR_FUNCTION_ARRAY_INTERSECT\x10x\x12\x1f\n\x1bSCALAR_FUNCTION_ARRAY_UNION\x10y\x12\x1c\n\x18SCALAR_FUNCTION_OVER_LAY\x10z\x12\x19\n\x15SCALAR_FUNCTION_RANGE\x10{\x12 \n\x1cSCALAR_FUNCTION_ARRAY_EXCEPT\x10|\x12#\n\x1fSCALAR_FUNCTION_ARRAY_POP_FRONT\x10}\x12\x1f\n\x1bSCALAR_FUNCTION_LEVENSHTEIN\x10~\x12 \n\x1cSCALAR_FUNCTION_SUBSTR_INDEX\x10\x7f\x12 \n\x1bSCALAR_FUNCTION_FIND_IN_SET\x10\x80\x01\x12\x1f\n\x1aSCALAR_FUNCTION_ARRAY_SORT\x10\x81\x01\x12#\n\x1eSCALAR_FUNCTION_ARRAY_DISTINCT\x10\x82\x01*\x8b\n\n\x11\x41ggregateFunction\x12"\n\x1e\x41GGREGATE_FUNCTION_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x41GGREGATE_FUNCTION_MIN\x10\x01\x12\x1a\n\x16\x41GGREGATE_FUNCTION_MAX\x10\x02\x12\x1a\n\x16\x41GGREGATE_FUNCTION_SUM\x10\x03\x12\x1a\n\x16\x41GGREGATE_FUNCTION_AVG\x10\x04\x12\x1c\n\x18\x41GGREGATE_FUNCTION_COUNT\x10\x05\x12&\n"AGGREGATE_FUNCTION_APPROX_DISTINCT\x10\x06\x12\x1c\n\x18\x41GGREGATE_FUNCTION_ARRAY\x10\x07\x12\x1f\n\x1b\x41GGREGATE_FUNCTION_VARIANCE\x10\x08\x12#\n\x1f\x41GGREGATE_FUNCTION_VARIANCE_POP\x10\t\x12!\n\x1d\x41GGREGATE_FUNCTION_COVARIANCE\x10\n\x12%\n!AGGREGATE_FUNCTION_COVARIANCE_POP\x10\x0b\x12\x1d\n\x19\x41GGREGATE_FUNCTION_STDDEV\x10\x0c\x12!\n\x1d\x41GGREGATE_FUNCTION_STDDEV_POP\x10\r\x12"\n\x1e\x41GGREGATE_FUNCTION_CORRELATION\x10\x0e\x12-\n)AGGREGATE_FUNCTION_APPROX_PERCENTILE_CONT\x10\x0f\x12$\n AGGREGATE_FUNCTION_APPROX_MEDIAN\x10\x10\x12\x39\n5AGGREGATE_FUNCTION_APPROX_PERCENTILE_CONT_WITH_WEIGHT\x10\x11\x12\x1f\n\x1b\x41GGREGATE_FUNCTION_GROUPING\x10\x12\x12\x1d\n\x19\x41GGREGATE_FUNCTION_MEDIAN\x10\x13\x12\x1e\n\x1a\x41GGREGATE_FUNCTION_BIT_AND\x10\x14\x12\x1d\n\x19\x41GGREGATE_FUNCTION_BIT_OR\x10\x15\x12\x1e\n\x1a\x41GGREGATE_FUNCTION_BIT_XOR\x10\x16\x12\x1f\n\x1b\x41GGREGATE_FUNCTION_BOOL_AND\x10\x17\x12\x1e\n\x1a\x41GGREGATE_FUNCTION_BOOL_OR\x10\x18\x12"\n\x1e\x41GGREGATE_FUNCTION_FIRST_VALUE\x10\x19\x12!\n\x1d\x41GGREGATE_FUNCTION_LAST_VALUE\x10\x1a\x12!\n\x1d\x41GGREGATE_FUNCTION_REGR_SLOPE\x10\x1b\x12%\n!AGGREGATE_FUNCTION_REGR_INTERCEPT\x10\x1c\x12!\n\x1d\x41GGREGATE_FUNCTION_REGR_COUNT\x10\x1d\x12\x1e\n\x1a\x41GGREGATE_FUNCTION_REGR_R2\x10\x1e\x12 \n\x1c\x41GGREGATE_FUNCTION_REGR_AVGX\x10\x1f\x12 \n\x1c\x41GGREGATE_FUNCTION_REGR_AVGY\x10 \x12\x1f\n\x1b\x41GGREGATE_FUNCTION_REGR_SXX\x10!\x12\x1f\n\x1b\x41GGREGATE_FUNCTION_REGR_SYY\x10"\x12\x1f\n\x1b\x41GGREGATE_FUNCTION_REGR_SXY\x10#\x12\x1d\n\x19\x41GGREGATE_FUNCTION_STRING\x10$*\xed\x03\n\x15\x42uiltInWindowFunction\x12(\n$BUILT_IN_WINDOW_FUNCTION_UNSPECIFIED\x10\x00\x12\'\n#BUILT_IN_WINDOW_FUNCTION_ROW_NUMBER\x10\x01\x12!\n\x1d\x42UILT_IN_WINDOW_FUNCTION_RANK\x10\x02\x12\'\n#BUILT_IN_WINDOW_FUNCTION_DENSE_RANK\x10\x03\x12)\n%BUILT_IN_WINDOW_FUNCTION_PERCENT_RANK\x10\x04\x12&\n"BUILT_IN_WINDOW_FUNCTION_CUME_DIST\x10\x05\x12"\n\x1e\x42UILT_IN_WINDOW_FUNCTION_NTILE\x10\x06\x12 \n\x1c\x42UILT_IN_WINDOW_FUNCTION_LAG\x10\x07\x12!\n\x1d\x42UILT_IN_WINDOW_FUNCTION_LEAD\x10\x08\x12(\n$BUILT_IN_WINDOW_FUNCTION_FIRST_VALUE\x10\t\x12\'\n#BUILT_IN_WINDOW_FUNCTION_LAST_VALUE\x10\n\x12&\n"BUILT_IN_WINDOW_FUNCTION_NTH_VALUE\x10\x0b*\x90\x01\n\x10WindowFrameUnits\x12"\n\x1eWINDOW_FRAME_UNITS_UNSPECIFIED\x10\x00\x12\x1b\n\x17WINDOW_FRAME_UNITS_ROWS\x10\x01\x12\x1c\n\x18WINDOW_FRAME_UNITS_RANGE\x10\x02\x12\x1d\n\x19WINDOW_FRAME_UNITS_GROUPS\x10\x03*\xb6\x01\n\x14WindowFrameBoundType\x12\'\n#WINDOW_FRAME_BOUND_TYPE_UNSPECIFIED\x10\x00\x12\'\n#WINDOW_FRAME_BOUND_TYPE_CURRENT_ROW\x10\x01\x12%\n!WINDOW_FRAME_BOUND_TYPE_PRECEDING\x10\x02\x12%\n!WINDOW_FRAME_BOUND_TYPE_FOLLOWING\x10\x03\x42\x98\x01\n\x17\x63om.chalk.expression.v1B\x0f\x45xpressionProtoP\x01\xa2\x02\x03\x43\x45X\xaa\x02\x13\x43halk.Expression.V1\xca\x02\x13\x43halk\\Expression\\V1\xe2\x02\x1f\x43halk\\Expression\\V1\\GPBMetadata\xea\x02\x15\x43halk::Expression::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.expression.v1.expression_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\027com.chalk.expression.v1B\017ExpressionProtoP\001\242\002\003CEX\252\002\023Chalk.Expression.V1\312\002\023Chalk\\Expression\\V1\342\002\037Chalk\\Expression\\V1\\GPBMetadata\352\002\025Chalk::Expression::V1"
    _globals["_EXPRCALL_KWARGSENTRY"]._options = None
    _globals["_EXPRCALL_KWARGSENTRY"]._serialized_options = b"8\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["column"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["column"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["alias"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["alias"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["literal"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["literal"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["binary_expr"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["binary_expr"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["aggregate_expr"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["aggregate_expr"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_null_expr"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_null_expr"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_not_null_expr"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_not_null_expr"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["not_expr"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["not_expr"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["between"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["between"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["case"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["case"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["cast"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["cast"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["sort"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["sort"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["negative"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["negative"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["in_list"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["in_list"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["wildcard"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["wildcard"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["scalar_function"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["scalar_function"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["try_cast"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["try_cast"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["window_expr"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["window_expr"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["aggregate_udf_expr"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["aggregate_udf_expr"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["scalar_udf_expr"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["scalar_udf_expr"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["get_indexed_field"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["get_indexed_field"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["grouping_set"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["grouping_set"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["cube"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["cube"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["rollup"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["rollup"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_true"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_true"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_false"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_false"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_unknown"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_unknown"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_not_true"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_not_true"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_not_false"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_not_false"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_not_unknown"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["is_not_unknown"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["like"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["like"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["ilike"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["ilike"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["similar_to"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["similar_to"]._serialized_options = b"\030\001"
    _globals["_LOGICALEXPRNODE"].fields_by_name["placeholder"]._options = None
    _globals["_LOGICALEXPRNODE"].fields_by_name["placeholder"]._serialized_options = b"\030\001"
    _globals["_AGGREGATEUDFEXPRNODE_KWARGSENTRY"]._options = None
    _globals["_AGGREGATEUDFEXPRNODE_KWARGSENTRY"]._serialized_options = b"8\001"
    _globals["_SCALARFUNCTION"]._serialized_start = 9817
    _globals["_SCALARFUNCTION"]._serialized_end = 13817
    _globals["_AGGREGATEFUNCTION"]._serialized_start = 13820
    _globals["_AGGREGATEFUNCTION"]._serialized_end = 15111
    _globals["_BUILTINWINDOWFUNCTION"]._serialized_start = 15114
    _globals["_BUILTINWINDOWFUNCTION"]._serialized_end = 15607
    _globals["_WINDOWFRAMEUNITS"]._serialized_start = 15610
    _globals["_WINDOWFRAMEUNITS"]._serialized_end = 15754
    _globals["_WINDOWFRAMEBOUNDTYPE"]._serialized_start = 15757
    _globals["_WINDOWFRAMEBOUNDTYPE"]._serialized_end = 15939
    _globals["_IDENTIFIER"]._serialized_start = 89
    _globals["_IDENTIFIER"]._serialized_end = 121
    _globals["_EXPRGETATTRIBUTE"]._serialized_start = 124
    _globals["_EXPRGETATTRIBUTE"]._serialized_end = 267
    _globals["_EXPRGETSUBSCRIPT"]._serialized_start = 270
    _globals["_EXPRGETSUBSCRIPT"]._serialized_end = 418
    _globals["_EXPRCALL"]._serialized_start = 421
    _globals["_EXPRCALL"]._serialized_end = 711
    _globals["_EXPRCALL_KWARGSENTRY"]._serialized_start = 616
    _globals["_EXPRCALL_KWARGSENTRY"]._serialized_end = 711
    _globals["_EXPRLITERAL"]._serialized_start = 713
    _globals["_EXPRLITERAL"]._serialized_end = 830
    _globals["_LOGICALEXPRNODE"]._serialized_start = 833
    _globals["_LOGICALEXPRNODE"]._serialized_end = 3618
    _globals["_COLUMNRELATION"]._serialized_start = 3620
    _globals["_COLUMNRELATION"]._serialized_end = 3664
    _globals["_COLUMN"]._serialized_start = 3666
    _globals["_COLUMN"]._serialized_end = 3759
    _globals["_WILDCARD"]._serialized_start = 3761
    _globals["_WILDCARD"]._serialized_end = 3820
    _globals["_PLACEHOLDERNODE"]._serialized_start = 3822
    _globals["_PLACEHOLDERNODE"]._serialized_end = 3911
    _globals["_LOGICALEXPRLIST"]._serialized_start = 3913
    _globals["_LOGICALEXPRLIST"]._serialized_end = 3988
    _globals["_GROUPINGSETNODE"]._serialized_start = 3990
    _globals["_GROUPINGSETNODE"]._serialized_end = 4065
    _globals["_CUBENODE"]._serialized_start = 4067
    _globals["_CUBENODE"]._serialized_end = 4135
    _globals["_ROLLUPNODE"]._serialized_start = 4137
    _globals["_ROLLUPNODE"]._serialized_end = 4207
    _globals["_NAMEDSTRUCTFIELD"]._serialized_start = 4209
    _globals["_NAMEDSTRUCTFIELD"]._serialized_end = 4276
    _globals["_LISTINDEX"]._serialized_start = 4278
    _globals["_LISTINDEX"]._serialized_end = 4345
    _globals["_LISTRANGE"]._serialized_start = 4348
    _globals["_LISTRANGE"]._serialized_end = 4477
    _globals["_GETINDEXEDFIELD"]._serialized_start = 4480
    _globals["_GETINDEXEDFIELD"]._serialized_end = 4781
    _globals["_ISNULL"]._serialized_start = 4783
    _globals["_ISNULL"]._serialized_end = 4849
    _globals["_ISNOTNULL"]._serialized_start = 4851
    _globals["_ISNOTNULL"]._serialized_end = 4920
    _globals["_ISTRUE"]._serialized_start = 4922
    _globals["_ISTRUE"]._serialized_end = 4988
    _globals["_ISFALSE"]._serialized_start = 4990
    _globals["_ISFALSE"]._serialized_end = 5057
    _globals["_ISUNKNOWN"]._serialized_start = 5059
    _globals["_ISUNKNOWN"]._serialized_end = 5128
    _globals["_ISNOTTRUE"]._serialized_start = 5130
    _globals["_ISNOTTRUE"]._serialized_end = 5199
    _globals["_ISNOTFALSE"]._serialized_start = 5201
    _globals["_ISNOTFALSE"]._serialized_end = 5271
    _globals["_ISNOTUNKNOWN"]._serialized_start = 5273
    _globals["_ISNOTUNKNOWN"]._serialized_end = 5345
    _globals["_NOT"]._serialized_start = 5347
    _globals["_NOT"]._serialized_end = 5410
    _globals["_ALIASNODE"]._serialized_start = 5413
    _globals["_ALIASNODE"]._serialized_end = 5574
    _globals["_BARETABLEREFERENCE"]._serialized_start = 5576
    _globals["_BARETABLEREFERENCE"]._serialized_end = 5618
    _globals["_PARTIALTABLEREFERENCE"]._serialized_start = 5620
    _globals["_PARTIALTABLEREFERENCE"]._serialized_end = 5689
    _globals["_FULLTABLEREFERENCE"]._serialized_start = 5691
    _globals["_FULLTABLEREFERENCE"]._serialized_end = 5783
    _globals["_OWNEDTABLEREFERENCE"]._serialized_start = 5786
    _globals["_OWNEDTABLEREFERENCE"]._serialized_end = 6029
    _globals["_BINARYEXPRNODE"]._serialized_start = 6031
    _globals["_BINARYEXPRNODE"]._serialized_end = 6129
    _globals["_NEGATIVENODE"]._serialized_start = 6131
    _globals["_NEGATIVENODE"]._serialized_end = 6203
    _globals["_INLISTNODE"]._serialized_start = 6206
    _globals["_INLISTNODE"]._serialized_end = 6360
    _globals["_SCALARFUNCTIONNODE"]._serialized_start = 6363
    _globals["_SCALARFUNCTIONNODE"]._serialized_end = 6496
    _globals["_AGGREGATEEXPRNODE"]._serialized_start = 6499
    _globals["_AGGREGATEEXPRNODE"]._serialized_end = 6808
    _globals["_AGGREGATEUDFEXPRNODE"]._serialized_start = 6811
    _globals["_AGGREGATEUDFEXPRNODE"]._serialized_end = 7221
    _globals["_AGGREGATEUDFEXPRNODE_KWARGSENTRY"]._serialized_start = 616
    _globals["_AGGREGATEUDFEXPRNODE_KWARGSENTRY"]._serialized_end = 711
    _globals["_SCALARUDFEXPRNODE"]._serialized_start = 7223
    _globals["_SCALARUDFEXPRNODE"]._serialized_end = 7327
    _globals["_WINDOWEXPRNODE"]._serialized_start = 7330
    _globals["_WINDOWEXPRNODE"]._serialized_end = 7843
    _globals["_BETWEENNODE"]._serialized_start = 7846
    _globals["_BETWEENNODE"]._serialized_end = 8057
    _globals["_LIKENODE"]._serialized_start = 8060
    _globals["_LIKENODE"]._serialized_end = 8251
    _globals["_ILIKENODE"]._serialized_start = 8254
    _globals["_ILIKENODE"]._serialized_end = 8446
    _globals["_SIMILARTONODE"]._serialized_start = 8449
    _globals["_SIMILARTONODE"]._serialized_end = 8645
    _globals["_CASENODE"]._serialized_start = 8648
    _globals["_CASENODE"]._serialized_end = 8852
    _globals["_WHENTHEN"]._serialized_start = 8855
    _globals["_WHENTHEN"]._serialized_end = 8999
    _globals["_CASTNODE"]._serialized_start = 9001
    _globals["_CASTNODE"]._serialized_end = 9127
    _globals["_TRYCASTNODE"]._serialized_start = 9130
    _globals["_TRYCASTNODE"]._serialized_end = 9259
    _globals["_SORTEXPRNODE"]._serialized_start = 9261
    _globals["_SORTEXPRNODE"]._serialized_end = 9384
    _globals["_WINDOWFRAME"]._serialized_start = 9387
    _globals["_WINDOWFRAME"]._serialized_end = 9633
    _globals["_WINDOWFRAMEBOUND"]._serialized_start = 9636
    _globals["_WINDOWFRAMEBOUND"]._serialized_end = 9814
# @@protoc_insertion_point(module_scope)



from chalk._gen.chalk.auth.v1 import permissions_pb2 as _permissions_pb2
from chalk._gen.chalk.graph.v1 import graph_pb2 as _graph_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class GetAllNamedQueriesRequest(_message.Message):
    __slots__ = ("deployment_id",)
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    def __init__(self, deployment_id: _Optional[str] = ...) -> None: ...

class GetNamedQueryByNameRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetNamedQueryByNameResponse(_message.Message):
    __slots__ = ("named_queries",)
    NAMED_QUERIES_FIELD_NUMBER: _ClassVar[int]
    named_queries: _containers.RepeatedCompositeFieldContainer[_graph_pb2.NamedQuery]
    def __init__(self, named_queries: _Optional[_Iterable[_Union[_graph_pb2.NamedQuery, _Mapping]]] = ...) -> None: ...

class GetAllNamedQueriesResponse(_message.Message):
    __slots__ = ("named_queries",)
    NAMED_QUERIES_FIELD_NUMBER: _ClassVar[int]
    named_queries: _containers.RepeatedCompositeFieldContainer[_graph_pb2.NamedQuery]
    def __init__(self, named_queries: _Optional[_Iterable[_Union[_graph_pb2.NamedQuery, _Mapping]]] = ...) -> None: ...

class GetAllNamedQueriesActiveDeploymentRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetAllNamedQueriesActiveDeploymentResponse(_message.Message):
    __slots__ = ("named_queries",)
    NAMED_QUERIES_FIELD_NUMBER: _ClassVar[int]
    named_queries: _containers.RepeatedCompositeFieldContainer[_graph_pb2.NamedQuery]
    def __init__(self, named_queries: _Optional[_Iterable[_Union[_graph_pb2.NamedQuery, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/chart/v1/densetimeserieschart.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chalk._gen.chalk.arrow.v1 import arrow_pb2 as chalk_dot_arrow_dot_v1_dot_arrow__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)chalk/chart/v1/densetimeserieschart.proto\x12\x0e\x63halk.chart.v1\x1a\x1a\x63halk/arrow/v1/arrow.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto"1\n\nDensePoint\x12\x19\n\x05value\x18\x01 \x01(\x01H\x00R\x05value\x88\x01\x01\x42\x08\n\x06_value"Z\n\x08GroupTag\x12\x1b\n\tgroup_key\x18\x01 \x01(\tR\x08groupKey\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\x1b.chalk.arrow.v1.ScalarValueR\x05value"\xa8\x01\n\x0f\x44\x65nseTimeSeries\x12\x32\n\x06points\x18\x01 \x03(\x0b\x32\x1a.chalk.chart.v1.DensePointR\x06points\x12\x14\n\x05label\x18\x02 \x01(\tR\x05label\x12\x12\n\x04unit\x18\x03 \x01(\tR\x04unit\x12\x37\n\ngroup_tags\x18\x04 \x03(\x0b\x32\x18.chalk.chart.v1.GroupTagR\tgroupTags"\xdc\x01\n\x14\x44\x65nseTimeSeriesChart\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12\x37\n\x06series\x18\x02 \x03(\x0b\x32\x1f.chalk.chart.v1.DenseTimeSeriesR\x06series\x12\x35\n\x08x_series\x18\x03 \x03(\x0b\x32\x1a.google.protobuf.TimestampR\x07xSeries\x12>\n\rwindow_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cwindowPeriodB\x9d\x01\n\x12\x63om.chalk.chart.v1B\x19\x44\x65nsetimeserieschartProtoP\x01Z\x12server/v1;serverv1\xa2\x02\x03\x43\x43X\xaa\x02\x0e\x43halk.Chart.V1\xca\x02\x0e\x43halk\\Chart\\V1\xe2\x02\x1a\x43halk\\Chart\\V1\\GPBMetadata\xea\x02\x10\x43halk::Chart::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.chart.v1.densetimeserieschart_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\022com.chalk.chart.v1B\031DensetimeserieschartProtoP\001Z\022server/v1;serverv1\242\002\003CCX\252\002\016Chalk.Chart.V1\312\002\016Chalk\\Chart\\V1\342\002\032Chalk\\Chart\\V1\\GPBMetadata\352\002\020Chalk::Chart::V1"
    _globals["_DENSEPOINT"]._serialized_start = 154
    _globals["_DENSEPOINT"]._serialized_end = 203
    _globals["_GROUPTAG"]._serialized_start = 205
    _globals["_GROUPTAG"]._serialized_end = 295
    _globals["_DENSETIMESERIES"]._serialized_start = 298
    _globals["_DENSETIMESERIES"]._serialized_end = 466
    _globals["_DENSETIMESERIESCHART"]._serialized_start = 469
    _globals["_DENSETIMESERIESCHART"]._serialized_end = 689
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/kubernetes/v1/pods.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1e\x63halk/kubernetes/v1/pods.proto\x12\x13\x63halk.kubernetes.v1"\xef\x41\n\x11KubernetesPodData\x12\x12\n\x04team\x18\x01 \x01(\tR\x04team\x12\x10\n\x03\x61pp\x18\x02 \x01(\tR\x03\x61pp\x12\x1c\n\tcomponent\x18\x03 \x01(\tR\tcomponent\x12\'\n\x0f\x64\x61tadog_service\x18\x04 \x01(\tR\x0e\x64\x61tadogService\x12\'\n\x0f\x64\x61tadog_version\x18\x05 \x01(\tR\x0e\x64\x61tadogVersion\x12*\n\x11pod_template_hash\x18\x06 \x01(\tR\x0fpodTemplateHash\x12H\n\x06status\x18\x07 \x01(\x0b\x32\x30.chalk.kubernetes.v1.KubernetesPodData.PodStatusR\x06status\x12\x42\n\x04spec\x18\x08 \x01(\x0b\x32..chalk.kubernetes.v1.KubernetesPodData.PodSpecR\x04spec\x12-\n\x12\x63reation_timestamp\x18\x12 \x01(\x03R\x11\x63reationTimestamp\x12-\n\x12\x64\x65letion_timestamp\x18\x13 \x01(\x03R\x11\x64\x65letionTimestamp\x12-\n\x12observed_timestamp\x18\x14 \x01(\x03R\x11observedTimestamp\x12J\n\x06labels\x18\x15 \x03(\x0b\x32\x32.chalk.kubernetes.v1.KubernetesPodData.LabelsEntryR\x06labels\x12Y\n\x0b\x61nnotations\x18\x16 \x03(\x0b\x32\x37.chalk.kubernetes.v1.KubernetesPodData.AnnotationsEntryR\x0b\x61nnotations\x12\x18\n\x07\x63luster\x18\x17 \x01(\tR\x07\x63luster\x12\x10\n\x03uid\x18\x18 \x01(\tR\x03uid\x12\x12\n\x04name\x18\x19 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x1a \x01(\tR\tnamespace\x1a\x1c\n\x06Volume\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x1a\xc1\x01\n\x0b\x43laimSource\x12\x33\n\x13resource_claim_name\x18\x01 \x01(\tH\x00R\x11resourceClaimName\x88\x01\x01\x12\x44\n\x1cresource_claim_template_name\x18\x02 \x01(\tH\x01R\x19resourceClaimTemplateName\x88\x01\x01\x42\x16\n\x14_resource_claim_nameB\x1f\n\x1d_resource_claim_template_name\x1a\x82\x01\n\x10PodResourceClaim\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12O\n\x06source\x18\x02 \x01(\x0b\x32\x32.chalk.kubernetes.v1.KubernetesPodData.ClaimSourceH\x00R\x06source\x88\x01\x01\x42\t\n\x07_source\x1a\xf6\r\n\x07PodSpec\x12G\n\x07volumes\x18\x01 \x03(\x0b\x32-.chalk.kubernetes.v1.KubernetesPodData.VolumeR\x07volumes\x12Y\n\x0finit_containers\x18\x14 \x03(\x0b\x32\x30.chalk.kubernetes.v1.KubernetesPodData.ContainerR\x0einitContainers\x12P\n\ncontainers\x18\x02 \x03(\x0b\x32\x30.chalk.kubernetes.v1.KubernetesPodData.ContainerR\ncontainers\x12*\n\x0erestart_policy\x18\x03 \x01(\tH\x00R\rrestartPolicy\x88\x01\x01\x12L\n termination_grace_period_seconds\x18\x04 \x01(\x03H\x01R\x1dterminationGracePeriodSeconds\x88\x01\x01\x12;\n\x17\x61\x63tive_deadline_seconds\x18\x05 \x01(\x03H\x02R\x15\x61\x63tiveDeadlineSeconds\x88\x01\x01\x12"\n\ndns_policy\x18\x06 \x01(\tH\x03R\tdnsPolicy\x88\x01\x01\x12\x65\n\rnode_selector\x18\x07 \x03(\x0b\x32@.chalk.kubernetes.v1.KubernetesPodData.PodSpec.NodeSelectorEntryR\x0cnodeSelector\x12\x35\n\x14service_account_name\x18\x08 \x01(\tH\x04R\x12serviceAccountName\x88\x01\x01\x12J\n\x1f\x61utomount_service_account_token\x18\x15 \x01(\x08H\x05R\x1c\x61utomountServiceAccountToken\x88\x01\x01\x12 \n\tnode_name\x18\n \x01(\tH\x06R\x08nodeName\x88\x01\x01\x12!\n\x0chost_network\x18\x0b \x01(\x08R\x0bhostNetwork\x12\x19\n\x08host_pid\x18\x0c \x01(\x08R\x07hostPid\x12\x19\n\x08host_ipc\x18\r \x01(\x08R\x07hostIpc\x12\x36\n\x17share_process_namespace\x18\x1b \x01(\x08R\x15shareProcessNamespace\x12\x1f\n\x08hostname\x18\x10 \x01(\tH\x07R\x08hostname\x88\x01\x01\x12!\n\tsubdomain\x18\x11 \x01(\tH\x08R\tsubdomain\x88\x01\x01\x12*\n\x0escheduler_name\x18\x13 \x01(\tH\tR\rschedulerName\x88\x01\x01\x12\x33\n\x13priority_class_name\x18\x18 \x01(\tH\nR\x11priorityClassName\x88\x01\x01\x12\x1f\n\x08priority\x18\x19 \x01(\x05H\x0bR\x08priority\x88\x01\x01\x12\x31\n\x12runtime_class_name\x18\x1d \x01(\tH\x0cR\x10runtimeClassName\x88\x01\x01\x12\x35\n\x14\x65nable_service_links\x18\x1e \x01(\x08H\rR\x12\x65nableServiceLinks\x88\x01\x01\x12\x30\n\x11preemption_policy\x18\x1f \x01(\tH\x0eR\x10preemptionPolicy\x88\x01\x01\x12"\n\nhost_users\x18% \x01(\x08H\x0fR\thostUsers\x88\x01\x01\x12`\n\x0fresource_claims\x18\' \x03(\x0b\x32\x37.chalk.kubernetes.v1.KubernetesPodData.PodResourceClaimR\x0eresourceClaims\x1a?\n\x11NodeSelectorEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x11\n\x0f_restart_policyB#\n!_termination_grace_period_secondsB\x1a\n\x18_active_deadline_secondsB\r\n\x0b_dns_policyB\x17\n\x15_service_account_nameB"\n _automount_service_account_tokenB\x0c\n\n_node_nameB\x0b\n\t_hostnameB\x0c\n\n_subdomainB\x11\n\x0f_scheduler_nameB\x16\n\x14_priority_class_nameB\x0b\n\t_priorityB\x15\n\x13_runtime_class_nameB\x17\n\x15_enable_service_linksB\x14\n\x12_preemption_policyB\r\n\x0b_host_users\x1a\xd7\x02\n\x0e\x43ontainerState\x12[\n\x07waiting\x18\x01 \x01(\x0b\x32<.chalk.kubernetes.v1.KubernetesPodData.ContainerStateWaitingH\x00R\x07waiting\x88\x01\x01\x12[\n\x07running\x18\x02 \x01(\x0b\x32<.chalk.kubernetes.v1.KubernetesPodData.ContainerStateRunningH\x01R\x07running\x88\x01\x01\x12\x64\n\nterminated\x18\x03 \x01(\x0b\x32?.chalk.kubernetes.v1.KubernetesPodData.ContainerStateTerminatedH\x02R\nterminated\x88\x01\x01\x42\n\n\x08_waitingB\n\n\x08_runningB\r\n\x0b_terminated\x1a\x36\n\x15\x43ontainerStateRunning\x12\x1d\n\nstarted_at\x18\x01 \x01(\x03R\tstartedAt\x1a\xd4\x02\n\x18\x43ontainerStateTerminated\x12\x1b\n\texit_code\x18\x01 \x01(\x05R\x08\x65xitCode\x12\x1b\n\x06signal\x18\x02 \x01(\x05H\x00R\x06signal\x88\x01\x01\x12\x1b\n\x06reason\x18\x03 \x01(\tH\x01R\x06reason\x88\x01\x01\x12\x1d\n\x07message\x18\x04 \x01(\tH\x02R\x07message\x88\x01\x01\x12"\n\nstarted_at\x18\x05 \x01(\x03H\x03R\tstartedAt\x88\x01\x01\x12$\n\x0b\x66inished_at\x18\x06 \x01(\x03H\x04R\nfinishedAt\x88\x01\x01\x12&\n\x0c\x63ontainer_id\x18\x07 \x01(\tH\x05R\x0b\x63ontainerId\x88\x01\x01\x42\t\n\x07_signalB\t\n\x07_reasonB\n\n\x08_messageB\r\n\x0b_started_atB\x0e\n\x0c_finished_atB\x0f\n\r_container_id\x1a\x9a\x01\n\x06\x45nvVar\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\x12W\n\nvalue_from\x18\x03 \x01(\x0b\x32\x33.chalk.kubernetes.v1.KubernetesPodData.EnvVarSourceH\x00R\tvalueFrom\x88\x01\x01\x42\r\n\x0b_value_from\x1a\x80\x04\n\x0c\x45nvVarSource\x12\\\n\tfield_ref\x18\x01 \x01(\x0b\x32:.chalk.kubernetes.v1.KubernetesPodData.ObjectFieldSelectorH\x00R\x08\x66ieldRef\x88\x01\x01\x12o\n\x12resource_field_ref\x18\x02 \x01(\x0b\x32<.chalk.kubernetes.v1.KubernetesPodData.ResourceFieldSelectorH\x01R\x10resourceFieldRef\x88\x01\x01\x12m\n\x12\x63onfig_map_key_ref\x18\x03 \x01(\x0b\x32;.chalk.kubernetes.v1.KubernetesPodData.ConfigMapKeySelectorH\x02R\x0f\x63onfigMapKeyRef\x88\x01\x01\x12\x63\n\x0esecret_key_ref\x18\x04 \x01(\x0b\x32\x38.chalk.kubernetes.v1.KubernetesPodData.SecretKeySelectorH\x03R\x0csecretKeyRef\x88\x01\x01\x42\x0c\n\n_field_refB\x15\n\x13_resource_field_refB\x15\n\x13_config_map_key_refB\x11\n\x0f_secret_key_ref\x1aU\n\x13ObjectFieldSelector\x12\x1f\n\x0b\x61pi_version\x18\x01 \x01(\tR\napiVersion\x12\x1d\n\nfield_path\x18\x02 \x01(\tR\tfieldPath\x1a\xb6\x01\n\x15ResourceFieldSelector\x12%\n\x0e\x63ontainer_name\x18\x01 \x01(\tR\rcontainerName\x12\x1a\n\x08resource\x18\x02 \x01(\tR\x08resource\x12N\n\x07\x64ivisor\x18\x03 \x01(\x0b\x32/.chalk.kubernetes.v1.KubernetesPodData.QuantityH\x00R\x07\x64ivisor\x88\x01\x01\x42\n\n\x08_divisor\x1aj\n\x14\x43onfigMapKeySelector\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x1f\n\x08optional\x18\x03 \x01(\x08H\x00R\x08optional\x88\x01\x01\x42\x0b\n\t_optional\x1ag\n\x11SecretKeySelector\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x1f\n\x08optional\x18\x03 \x01(\x08H\x00R\x08optional\x88\x01\x01\x42\x0b\n\t_optional\x1a\x9b\x02\n\rEnvFromSource\x12\x1b\n\x06prefix\x18\x01 \x01(\tH\x00R\x06prefix\x88\x01\x01\x12\x64\n\x0e\x63onfig_map_ref\x18\x02 \x01(\x0b\x32\x39.chalk.kubernetes.v1.KubernetesPodData.ConfigMapEnvSourceH\x01R\x0c\x63onfigMapRef\x88\x01\x01\x12Z\n\nsecret_ref\x18\x03 \x01(\x0b\x32\x36.chalk.kubernetes.v1.KubernetesPodData.SecretEnvSourceH\x02R\tsecretRef\x88\x01\x01\x42\t\n\x07_prefixB\x11\n\x0f_config_map_refB\r\n\x0b_secret_ref\x1aV\n\x12\x43onfigMapEnvSource\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1f\n\x08optional\x18\x02 \x01(\x08H\x00R\x08optional\x88\x01\x01\x42\x0b\n\t_optional\x1aS\n\x0fSecretEnvSource\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1f\n\x08optional\x18\x02 \x01(\x08H\x00R\x08optional\x88\x01\x01\x42\x0b\n\t_optional\x1a\xb3\x06\n\tContainer\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x19\n\x05image\x18\x02 \x01(\tH\x00R\x05image\x88\x01\x01\x12\x18\n\x07\x63ommand\x18\x03 \x03(\tR\x07\x63ommand\x12\x12\n\x04\x61rgs\x18\x04 \x03(\tR\x04\x61rgs\x12$\n\x0bworking_dir\x18\x05 \x01(\tH\x01R\nworkingDir\x88\x01\x01\x12O\n\x08\x65nv_from\x18\x13 \x03(\x0b\x32\x34.chalk.kubernetes.v1.KubernetesPodData.EnvFromSourceR\x07\x65nvFrom\x12?\n\x03\x65nv\x18\x07 \x03(\x0b\x32-.chalk.kubernetes.v1.KubernetesPodData.EnvVarR\x03\x65nv\x12^\n\tresources\x18\x08 \x01(\x0b\x32;.chalk.kubernetes.v1.KubernetesPodData.ResourceRequirementsH\x02R\tresources\x88\x01\x01\x12*\n\x0erestart_policy\x18\x18 \x01(\tH\x03R\rrestartPolicy\x88\x01\x01\x12=\n\x18termination_message_path\x18\r \x01(\tH\x04R\x16terminationMessagePath\x88\x01\x01\x12\x41\n\x1atermination_message_policy\x18\x14 \x01(\tH\x05R\x18terminationMessagePolicy\x88\x01\x01\x12/\n\x11image_pull_policy\x18\x0e \x01(\tH\x06R\x0fimagePullPolicy\x88\x01\x01\x12\x14\n\x05stdin\x18\x10 \x01(\x08R\x05stdin\x12\x1d\n\nstdin_once\x18\x11 \x01(\x08R\tstdinOnce\x12\x10\n\x03tty\x18\x12 \x01(\x08R\x03ttyB\x08\n\x06_imageB\x0e\n\x0c_working_dirB\x0c\n\n_resourcesB\x11\n\x0f_restart_policyB\x1b\n\x19_termination_message_pathB\x1d\n\x1b_termination_message_policyB\x14\n\x12_image_pull_policy\x1aj\n\x15\x43ontainerStateWaiting\x12\x1b\n\x06reason\x18\x01 \x01(\tH\x00R\x06reason\x88\x01\x01\x12\x1d\n\x07message\x18\x02 \x01(\tH\x01R\x07message\x88\x01\x01\x42\t\n\x07_reasonB\n\n\x08_message\x1a\xa3\x03\n\x0f\x43ontainerStatus\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12P\n\x05state\x18\x02 \x01(\x0b\x32\x35.chalk.kubernetes.v1.KubernetesPodData.ContainerStateH\x00R\x05state\x88\x01\x01\x12Y\n\nlast_state\x18\x03 \x01(\x0b\x32\x35.chalk.kubernetes.v1.KubernetesPodData.ContainerStateH\x01R\tlastState\x88\x01\x01\x12\x19\n\x05ready\x18\x04 \x01(\x08H\x02R\x05ready\x88\x01\x01\x12#\n\rrestart_count\x18\x05 \x01(\x05R\x0crestartCount\x12\x14\n\x05image\x18\x06 \x01(\tR\x05image\x12\x19\n\x08image_id\x18\x07 \x01(\tR\x07imageId\x12!\n\x0c\x63ontainer_id\x18\x08 \x01(\tR\x0b\x63ontainerId\x12\x18\n\x07started\x18\t \x01(\x08R\x07startedB\x08\n\x06_stateB\r\n\x0b_last_stateB\x08\n\x06_ready\x1a\x32\n\x08Quantity\x12\x1b\n\x06string\x18\x01 \x01(\tH\x00R\x06string\x88\x01\x01\x42\t\n\x07_string\x1a\xb8\x03\n\x14ResourceRequirements\x12_\n\x06limits\x18\x01 \x03(\x0b\x32G.chalk.kubernetes.v1.KubernetesPodData.ResourceRequirements.LimitsEntryR\x06limits\x12\x65\n\x08requests\x18\x02 \x03(\x0b\x32I.chalk.kubernetes.v1.KubernetesPodData.ResourceRequirements.RequestsEntryR\x08requests\x1aj\n\x0bLimitsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x45\n\x05value\x18\x02 \x01(\x0b\x32/.chalk.kubernetes.v1.KubernetesPodData.QuantityR\x05value:\x02\x38\x01\x1al\n\rRequestsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x45\n\x05value\x18\x02 \x01(\x0b\x32/.chalk.kubernetes.v1.KubernetesPodData.QuantityR\x05value:\x02\x38\x01\x1a\xe7\x01\n\x0cPodCondition\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x16\n\x06status\x18\x02 \x01(\tR\x06status\x12&\n\x0flast_probe_time\x18\x03 \x01(\x03R\rlastProbeTime\x12\x30\n\x14last_transition_time\x18\x04 \x01(\x03R\x12lastTransitionTime\x12\x1b\n\x06reason\x18\x05 \x01(\tH\x00R\x06reason\x88\x01\x01\x12\x1d\n\x07message\x18\x06 \x01(\tH\x01R\x07message\x88\x01\x01\x42\t\n\x07_reasonB\n\n\x08_message\x1a$\n\x06HostIP\x12\x13\n\x02ip\x18\x01 \x01(\tH\x00R\x02ip\x88\x01\x01\x42\x05\n\x03_ip\x1a\x9c\x07\n\tPodStatus\x12\x19\n\x05phase\x18\x01 \x01(\tH\x00R\x05phase\x88\x01\x01\x12S\n\nconditions\x18\x02 \x03(\x0b\x32\x33.chalk.kubernetes.v1.KubernetesPodData.PodConditionR\nconditions\x12\x1d\n\x07message\x18\x03 \x01(\tH\x01R\x07message\x88\x01\x01\x12\x1b\n\x06reason\x18\x04 \x01(\tH\x02R\x06reason\x88\x01\x01\x12\x33\n\x13nominated_node_name\x18\x0b \x01(\tH\x03R\x11nominatedNodeName\x88\x01\x01\x12\x1c\n\x07host_ip\x18\x05 \x01(\tH\x04R\x06hostIp\x88\x01\x01\x12H\n\x08host_ips\x18\x10 \x03(\x0b\x32-.chalk.kubernetes.v1.KubernetesPodData.HostIPR\x07hostIps\x12\x1a\n\x06pod_ip\x18\x06 \x01(\tH\x05R\x05podIp\x88\x01\x01\x12"\n\nstart_time\x18\x07 \x01(\x03H\x06R\tstartTime\x88\x01\x01\x12n\n\x17init_container_statuses\x18\n \x03(\x0b\x32\x36.chalk.kubernetes.v1.KubernetesPodData.ContainerStatusR\x15initContainerStatuses\x12\x65\n\x12\x63ontainer_statuses\x18\x08 \x03(\x0b\x32\x36.chalk.kubernetes.v1.KubernetesPodData.ContainerStatusR\x11\x63ontainerStatuses\x12 \n\tqos_class\x18\t \x01(\tH\x07R\x08qosClass\x88\x01\x01\x12x\n\x1c\x65phemeral_container_statuses\x18\r \x03(\x0b\x32\x36.chalk.kubernetes.v1.KubernetesPodData.ContainerStatusR\x1a\x65phemeralContainerStatuses\x12\x1b\n\x06resize\x18\x0e \x01(\tH\x08R\x06resize\x88\x01\x01\x42\x08\n\x06_phaseB\n\n\x08_messageB\t\n\x07_reasonB\x16\n\x14_nominated_node_nameB\n\n\x08_host_ipB\t\n\x07_pod_ipB\r\n\x0b_start_timeB\x0c\n\n_qos_classB\t\n\x07_resize\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xae\x01\n\x17\x63om.chalk.kubernetes.v1B\tPodsProtoP\x01Z\x1akubernetes/v1;kubernetesv1\xa2\x02\x03\x43KX\xaa\x02\x13\x43halk.Kubernetes.V1\xca\x02\x13\x43halk\\Kubernetes\\V1\xe2\x02\x1f\x43halk\\Kubernetes\\V1\\GPBMetadata\xea\x02\x15\x43halk::Kubernetes::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.kubernetes.v1.pods_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\027com.chalk.kubernetes.v1B\tPodsProtoP\001Z\032kubernetes/v1;kubernetesv1\242\002\003CKX\252\002\023Chalk.Kubernetes.V1\312\002\023Chalk\\Kubernetes\\V1\342\002\037Chalk\\Kubernetes\\V1\\GPBMetadata\352\002\025Chalk::Kubernetes::V1"
    _globals["_KUBERNETESPODDATA_PODSPEC_NODESELECTORENTRY"]._options = None
    _globals["_KUBERNETESPODDATA_PODSPEC_NODESELECTORENTRY"]._serialized_options = b"8\001"
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS_LIMITSENTRY"]._options = None
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS_LIMITSENTRY"]._serialized_options = b"8\001"
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS_REQUESTSENTRY"]._options = None
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS_REQUESTSENTRY"]._serialized_options = b"8\001"
    _globals["_KUBERNETESPODDATA_LABELSENTRY"]._options = None
    _globals["_KUBERNETESPODDATA_LABELSENTRY"]._serialized_options = b"8\001"
    _globals["_KUBERNETESPODDATA_ANNOTATIONSENTRY"]._options = None
    _globals["_KUBERNETESPODDATA_ANNOTATIONSENTRY"]._serialized_options = b"8\001"
    _globals["_KUBERNETESPODDATA"]._serialized_start = 56
    _globals["_KUBERNETESPODDATA"]._serialized_end = 8487
    _globals["_KUBERNETESPODDATA_VOLUME"]._serialized_start = 815
    _globals["_KUBERNETESPODDATA_VOLUME"]._serialized_end = 843
    _globals["_KUBERNETESPODDATA_CLAIMSOURCE"]._serialized_start = 846
    _globals["_KUBERNETESPODDATA_CLAIMSOURCE"]._serialized_end = 1039
    _globals["_KUBERNETESPODDATA_PODRESOURCECLAIM"]._serialized_start = 1042
    _globals["_KUBERNETESPODDATA_PODRESOURCECLAIM"]._serialized_end = 1172
    _globals["_KUBERNETESPODDATA_PODSPEC"]._serialized_start = 1175
    _globals["_KUBERNETESPODDATA_PODSPEC"]._serialized_end = 2957
    _globals["_KUBERNETESPODDATA_PODSPEC_NODESELECTORENTRY"]._serialized_start = 2552
    _globals["_KUBERNETESPODDATA_PODSPEC_NODESELECTORENTRY"]._serialized_end = 2615
    _globals["_KUBERNETESPODDATA_CONTAINERSTATE"]._serialized_start = 2960
    _globals["_KUBERNETESPODDATA_CONTAINERSTATE"]._serialized_end = 3303
    _globals["_KUBERNETESPODDATA_CONTAINERSTATERUNNING"]._serialized_start = 3305
    _globals["_KUBERNETESPODDATA_CONTAINERSTATERUNNING"]._serialized_end = 3359
    _globals["_KUBERNETESPODDATA_CONTAINERSTATETERMINATED"]._serialized_start = 3362
    _globals["_KUBERNETESPODDATA_CONTAINERSTATETERMINATED"]._serialized_end = 3702
    _globals["_KUBERNETESPODDATA_ENVVAR"]._serialized_start = 3705
    _globals["_KUBERNETESPODDATA_ENVVAR"]._serialized_end = 3859
    _globals["_KUBERNETESPODDATA_ENVVARSOURCE"]._serialized_start = 3862
    _globals["_KUBERNETESPODDATA_ENVVARSOURCE"]._serialized_end = 4374
    _globals["_KUBERNETESPODDATA_OBJECTFIELDSELECTOR"]._serialized_start = 4376
    _globals["_KUBERNETESPODDATA_OBJECTFIELDSELECTOR"]._serialized_end = 4461
    _globals["_KUBERNETESPODDATA_RESOURCEFIELDSELECTOR"]._serialized_start = 4464
    _globals["_KUBERNETESPODDATA_RESOURCEFIELDSELECTOR"]._serialized_end = 4646
    _globals["_KUBERNETESPODDATA_CONFIGMAPKEYSELECTOR"]._serialized_start = 4648
    _globals["_KUBERNETESPODDATA_CONFIGMAPKEYSELECTOR"]._serialized_end = 4754
    _globals["_KUBERNETESPODDATA_SECRETKEYSELECTOR"]._serialized_start = 4756
    _globals["_KUBERNETESPODDATA_SECRETKEYSELECTOR"]._serialized_end = 4859
    _globals["_KUBERNETESPODDATA_ENVFROMSOURCE"]._serialized_start = 4862
    _globals["_KUBERNETESPODDATA_ENVFROMSOURCE"]._serialized_end = 5145
    _globals["_KUBERNETESPODDATA_CONFIGMAPENVSOURCE"]._serialized_start = 5147
    _globals["_KUBERNETESPODDATA_CONFIGMAPENVSOURCE"]._serialized_end = 5233
    _globals["_KUBERNETESPODDATA_SECRETENVSOURCE"]._serialized_start = 5235
    _globals["_KUBERNETESPODDATA_SECRETENVSOURCE"]._serialized_end = 5318
    _globals["_KUBERNETESPODDATA_CONTAINER"]._serialized_start = 5321
    _globals["_KUBERNETESPODDATA_CONTAINER"]._serialized_end = 6140
    _globals["_KUBERNETESPODDATA_CONTAINERSTATEWAITING"]._serialized_start = 6142
    _globals["_KUBERNETESPODDATA_CONTAINERSTATEWAITING"]._serialized_end = 6248
    _globals["_KUBERNETESPODDATA_CONTAINERSTATUS"]._serialized_start = 6251
    _globals["_KUBERNETESPODDATA_CONTAINERSTATUS"]._serialized_end = 6670
    _globals["_KUBERNETESPODDATA_QUANTITY"]._serialized_start = 6672
    _globals["_KUBERNETESPODDATA_QUANTITY"]._serialized_end = 6722
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS"]._serialized_start = 6725
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS"]._serialized_end = 7165
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS_LIMITSENTRY"]._serialized_start = 6949
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS_LIMITSENTRY"]._serialized_end = 7055
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS_REQUESTSENTRY"]._serialized_start = 7057
    _globals["_KUBERNETESPODDATA_RESOURCEREQUIREMENTS_REQUESTSENTRY"]._serialized_end = 7165
    _globals["_KUBERNETESPODDATA_PODCONDITION"]._serialized_start = 7168
    _globals["_KUBERNETESPODDATA_PODCONDITION"]._serialized_end = 7399
    _globals["_KUBERNETESPODDATA_HOSTIP"]._serialized_start = 7401
    _globals["_KUBERNETESPODDATA_HOSTIP"]._serialized_end = 7437
    _globals["_KUBERNETESPODDATA_PODSTATUS"]._serialized_start = 7440
    _globals["_KUBERNETESPODDATA_PODSTATUS"]._serialized_end = 8364
    _globals["_KUBERNETESPODDATA_LABELSENTRY"]._serialized_start = 8366
    _globals["_KUBERNETESPODDATA_LABELSENTRY"]._serialized_end = 8423
    _globals["_KUBERNETESPODDATA_ANNOTATIONSENTRY"]._serialized_start = 8425
    _globals["_KUBERNETESPODDATA_ANNOTATIONSENTRY"]._serialized_end = 8487
# @@protoc_insertion_point(module_scope)
